@@ -1,4 +1,4 @@
-# Copyright (C) 2007-2020 Gaetan Delannay
+# Copyright (C) 2007-2021 Gaetan Delannay
 
 # This file is part of Appy.
 
@@ -53,7 +53,7 @@ class Date(Field):
     pxHour = Hour.pxEdit
 
     pxEdit = Px('''
-     <x var="years=field.getSelectableYears()">
+     <x var="years=field.getSelectableYears(zobj)">
       <!-- Day -->
       <select if="field.showDay" var2="days=range(1,32); part='%s_day' % name"
               name=":part" id=":part">
@@ -93,7 +93,7 @@ class Date(Field):
      </x>''')
 
     pxSearch = Px('''
-     <table var="years=range(field.startYear, field.endYear+1);
+     <table var="years=field.getSelectableYears(zobj);
                  dstart,dend=field.getDefaultSearchValues(zobj)">
        <!-- From -->
        <tr var="fromName='%s_from' % name;
@@ -114,7 +114,7 @@ class Date(Field):
          </select> / 
          <select id=":widgetName" name=":widgetName">
           <option value="">--</option>
-          <option for="value in range(field.startYear, field.endYear+1)"
+          <option for="value in years"
                   value=":value" selected=":value == dstart[0]">:value</option>
          </select>
          <!-- The icon for displaying the calendar popup -->
@@ -151,7 +151,7 @@ class Date(Field):
          </select> / 
          <select id=":yearToName" name=":yearToName">
           <option value="">--</option>
-          <option for="value in range(field.startYear, field.endYear+1)"
+          <option for="value in years"
                   value=":value" selected=":value == dend[0]">:value</option>
          </select>
          <!-- The icon for displaying the calendar popup -->
@@ -236,11 +236,12 @@ class Date(Field):
         # Javascript files are only required if the calendar must be shown
         if self.calendar: Field.getJs(self, layoutType, res, config)
 
-    def getSelectableYears(self):
-        '''Gets the list of years one may select for this field.'''
-        res = range(self.startYear, self.endYear + 1)
-        if self.reverseYears: res.reverse()
-        return res
+    def getSelectableYears(self, obj):
+        '''Gets the list of years one may select for this field'''
+        startYear = self.getAttribute(obj, 'startYear')
+        r = range(startYear, self.endYear + 1)
+        if self.reverseYears: r.reverse()
+        return r
 
     def validateValue(self, obj, value):
         DateTime = obj.getProductConfig().DateTime
