@@ -1,4 +1,4 @@
-# Copyright (C) 2007-2020 Gaetan Delannay
+# Copyright (C) 2007-2021 Gaetan Delannay
 
 # This file is part of Appy.
 
@@ -151,9 +151,20 @@ class Hour(Field):
         hours = int(minutes / 60.0)
         return hours, mins
 
+    @classmethod
+    def fromString(class_, s, sep=':'):
+        '''Converts the string representation p_s of an hour (ie, "1:15",
+           "-0:30", "165:34", "00:00"...) into a integer number of minutes.'''
+        negate = s.startswith('-')
+        h, m = s.split(sep)
+        r = class_.getMinutes((abs(int(h)), int(m)))
+        if negate: r = -r
+        return r
+
     @classmethod
     def getDuration(class_, start, end):
-        '''Returns the duration, in minutes, of the interval [start, end]'''
+        '''Returns the duration, in minutes, of the interval [start, end],
+           "start" and "end" each being of the form ~(i_hours, i_minutes)~.'''
         # Manage minutes
         minutes = end[1] - start[1]
         if minutes < 0:
