@@ -28,9 +28,9 @@ class Multilingual:
     '''Mixin class injected into any Field whose content can be multilingual'''
 
     # Default values to render when field values are empty
-    emptyDefault = {'view': '-', 'edit': ''}
+    emptyDefault = {'view': '-', 'edit': '', 'cell': ''}
     # Default top space (in pixels) to apply in pxLanguage
-    lgTop = {'view': 1, 'edit': 3}
+    lgTop = {'view': 1, 'edit': 3, 'cell': 3}
 
     # Note that multilinguality is a dynamic feature: field values can be
     # unilingual or multilingual, depending on some condition on the container
