@@ -514,7 +514,7 @@ class Pod(Field):
         return res
 
     def getDownloadName(self, obj, template, format=None, queryRelated=False,
-                        bypassMethod=False):
+                        bypassMethod=False, titleMethod=None):
         '''Gets the name of the pod result as will be seen by the user that will
            download it. Ensure the returned name is not too long for the OS that
            will store the downloaded file with this name.'''
@@ -529,8 +529,13 @@ class Pod(Field):
         fileName = norm(self.getTemplateName(obj, template))[:40]
         if not queryRelated:
             # This is a POD for a single object: personalize the file name with
-            # the object title.
-            title = obj.o.getShownValue('title')
+            # the object title. If the name of a method is passed in
+            # p_titleMethod, it will be used on p_obj instead of getting its
+            # title via standard method m_getShownValue.
+            if titleMethod:
+                title = getattr(obj, titleMethod)()
+            else:
+                title = obj.o.getShownValue('title')
             fileName = '%s-%s' % (norm(title)[:40], fileName)
         return format and ('%s.%s' % (fileName, format)) or fileName
 
