@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2007-2020 Gaetan Delannay
+# Copyright (C) 2007-2021 Gaetan Delannay
 
 # This file is part of Appy.
 
@@ -191,7 +191,7 @@ class List(Mode):
               class="clickable" title=":_('check_uncheck')"
               onclick=":'toggleAllCbs(%s)' % q(mode.checkboxesId)"/>
          <x if="not column.special">
-          <x>::ztool.truncateText(_(field.labelId))</x>
+          <div>::ztool.truncateText(_(field.labelId))</div>
           <!-- Sort icons -->
           <x var="sortable=field.isSortable(usage='search')"
              if="sortable and (mode.batch.total &gt; 1)">
@@ -255,7 +255,7 @@ class List(Mode):
         start = int(req.get('startNumber', '0'))
         self.sortKey = req.get('sortKey', '')
         self.sortOrder = req.get('sortOrder', 'asc')
-        self.filters = sutils.getDictFrom(req.get('filters'))
+        self.filters = tool.getFilters(self.klass)
         # Execute the query
         r = tool.executeQuery(self.className, search=search.search,
           startNumber=start, remember=True, sortBy=self.sortKey,
@@ -326,6 +326,13 @@ class List(Mode):
             r.append('%s:%s' % (k, v))
         return ','.join(r)
 
+    def inFilter(self, name, value):
+        '''Returns True if this p_value, for field named p_name, is among the
+           currently set p_self.filters.'''
+        values = self.filters.get(name)
+        if not values: return
+        return value in values
+
     def getNavInfo(self, number):
         '''Gets the navigation string corresponding to the element having this
            p_number within the list of results.'''
@@ -430,7 +437,7 @@ class Calendar(Mode):
         # Format for representing hours in the UI
         self.hourFormat = '%H:%M'
         # If filters are defined from a list mode, get it
-        self.filters = sutils.getDictFrom(req.get('filters'))
+        self.filters = self.tool.getFilters(self.klass)
 
     def updateAjaxParameters(self, params):
         '''Grid-specific ajax parameters'''
