@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2007-2020 Gaetan Delannay
+# Copyright (C) 2007-2021 Gaetan Delannay
 
 # This file is part of Appy.
 
@@ -24,12 +24,12 @@ from appy.gen.indexer import ValidValue
 
 # ------------------------------------------------------------------------------
 emptyTuple = ()
-WRONG_RADIOS = 'You cannot render this field as radio buttons if it may ' \
-  'contain several values (max multiplicity is higher than 1).'
-WRONG_CHECKBOXES = 'You cannot render this field as checkboxes if it can ' \
-  'only contain a single value (max multiplicity is 1).'
-WRONG_INLINEDIT = 'It is currently not possible to inline-edit a multi-' \
-  'valued Select field.'
+RADIOS_KO = "This field can't be rendered as radio buttons because it may " \
+            "contain several values (max multiplicity is higher than 1)."
+CBS_KO    = "This field can't be rendered as checkboxes because it can " \
+            "only contain a single value (max multiplicity is 1)."
+IEDIT_KO  = 'It is currently not possible to inline-edit a multi-valued ' \
+            'Select field.'
 
 # ------------------------------------------------------------------------------
 class Selection:
@@ -207,12 +207,12 @@ class Select(Field):
         # Valid render modes depend on multiplicities
         multiple = self.isMultiValued()
         if multiple and (self.render == 'radio'):
-            raise Exception(WRONG_RADIOS)
+            raise Exception(RADIOS_KO)
         if not multiple and (self.render == 'checkbox'):
-            raise Exception(WRONG_CHECKBOXES)
+            raise Exception(CBS_KO)
         # It is currently not possible to inline-edit a multi-valued field
         if multiple and self.inlineEdit:
-            raise Exception(WRONG_INLINEDIT)
+            raise Exception(IEDIT_KO)
 
     def isSelected(self, obj, name, possibleValue, dbValue):
         '''When displaying a Select field, must the p_possibleValue appear as
@@ -244,27 +244,37 @@ class Select(Field):
             value = list(value)
         return value
 
+    def getTranslatedValue(self, obj, value, language=None):
+        '''Get the translated text for p_value, when p_value is one of p_self's
+           authorized "static" values according to its p_self.validator (being a
+           list or tuple o values).'''
+        if self.translations:
+            # Translations are available via a FieldTranslations instance
+            language = language or obj.getUserLanguage()
+            r = self.translations.get('value', language, value=value)
+        else:
+            r = obj.translate('%s_list_%s' % (self.labelId, value))
+        return r
+
     def getFormattedValue(self, obj, value, layoutType='view',
                           showChanges=False, language=None):
         '''Select-specific value formatting'''
         # Return an empty string if there is no p_value
         if Field.isEmptyValue(self, obj, value) and not showChanges: return ''
-        r = value
         if isinstance(self.validator, Selection):
             # Value(s) come from a dynamic vocabulary
             val = self.validator
             if self.isMultiValued():
-                return [val.getText(obj, v, self, language) for v in value]
+                r = [val.getText(obj, v, self, language) for v in value]
             else:
-                return val.getText(obj, value, self, language)
+                r = val.getText(obj, value, self, language)
         else:
             # Values come from a fixed vocabulary whose texts are in i18n files
-            _ = obj.translate
+            _ = self.getTranslatedValue
             if self.isMultiValued():
-                r = [_('%s_list_%s' % (self.labelId, v), language=language) \
-                     for v in value]
+                r = [_(obj, v, language=language) for v in value]
             else:
-                r = _('%s_list_%s' % (self.labelId, value), language=language)
+                r = _(obj, value, language=language)
         return r
 
     def getPossibleValues(self, obj, withTranslations=False,
@@ -350,13 +360,12 @@ class Select(Field):
                 if not withTranslations: res = [v[0] for v in res]
                 elif isinstance(res, list): res = res[:]
             else:
-                # The list of (static) values is directly given in
-                # self.validator.
+                # The list of (static) values is in self.validator
                 res = []
                 for value in self.validator:
-                    label = '%s_list_%s' % (self.labelId, value)
                     if withTranslations:
-                        res.append( (value, obj.translate(label, language=lg)) )
+                        text = self.getTranslatedValue(obj, value, language=lg)
+                        res.append((value, text))
                     else:
                         res.append(value)
         if (withBlankValue == 'forced') or \
