@@ -719,7 +719,7 @@ class Text(Multilingual, Field):
         if Field.isEmptyValue(self, obj, value) and not showChanges: return ''
         r = value
         if layoutType in ('view', 'cell'):
-            r = Escape.xhtml(res, p=True)
+            r = Escape.xhtml(r, p=True)
         # If value starts with a carriage return, add a space; else, it will
         # be ignored.
         elif isinstance(r, basestring) and \
