@@ -268,10 +268,6 @@ class Config:
     # discreet. This is for sites where authentication is not foreseen for
     # the majority of visitors (just for some administrators).
     discreetLogin = False
-    # If the following attribute is True, a comment within an object's history
-    # will be editable, either by a Manager or by the user having performed the
-    # corresponding action.
-    editHistoryComments = False
     # On user log on, you may want to ask them to choose their "authentication
     # context" in a list. Such a context may have any semantics, is coded as a
     # string and will be accessible on the Request object in attribute
