@@ -204,7 +204,7 @@ class ToolMixin(BaseMixin):
         # Ensure this is a string
         if not isinstance(res, basestring): res = str(res)
         # Remove <br/> tags
-        if '<br/>' in res: res = res[:res.index('<br/>')]
+        if '</p>' in res: res = res[3:res.index('</p>')]
         # Add the page title if found
         if obj and ('page' in self.REQUEST):
             pageLabel = '%s_page_%s' % (obj.meta_type, self.REQUEST['page'])
