@@ -284,7 +284,8 @@ class Page(ModelClass):
     doc = gen.Pod(template='/gen/templates/Page.odt', formats=('pdf',),
                   show=False, layouts=gen.Table('f', width=None,
                                                 css_class='inline', align=''))
-    title = gen.String(show='edit', multiplicity=(1,1), indexed=True, **pa)
+    title = gen.String(show=('edit','xml'), multiplicity=(1,1),
+                       indexed=True, **pa)
     content = gen.String(format=gen.String.XHTML, layouts='f')
     # If this Python expression returns False, the page can't be viewed
     def showExpression(self): pass
@@ -293,7 +294,7 @@ class Page(ModelClass):
     def showSubPages(self): pass
     pages = gen.Ref(None, multiplicity=(0,None), add=True, link=False,
       composite=True, back=gen.Ref(attribute='parent', show=False, **pa),
-      numbered=True, show=showSubPages, navigable=True, **pa)
+      numbered=True, show=showSubPages, **pa)
 Page.pages.klass = Page
 setattr(Page, Page.pages.back.attribute, Page.pages.back)
 
@@ -354,7 +355,7 @@ class Tool(ModelClass):
     loadTranslationsAtStartup = gen.Boolean(default=True, show=False, page=pt,
                                             layouts='f')
     pages = gen.Ref(Page, multiplicity=(0,None), add=True, link=False,
-      composite=True, show='view', actionsDisplay='inline',
+      composite=True, show=('view', 'xml'), actionsDisplay='inline',
       back=gen.Ref(attribute='toTool3', show=False, layouts='f'),
       page=gen.Page('pages', show=pageForToolWriters, label='Tool_page_pages'),
       **ta)
