@@ -734,6 +734,15 @@ function toggleAllCbs(id) {
   initCbs(id);
 }
 
+// Toggle all checkboxes of a Ref or Select rendered on "edit" as checkboxes
+function toggleCheckboxes(cb) {
+  var name=cb.id.substring(0, cb.id.length-4),
+      checkboxes = getElementsHavingName('input', name, true);
+  for (var i=0; i < checkboxes.length; i++) {
+    checkboxes[i].checked = cb.checked;
+  }
+}
+
 // Shows/hides a dropdown menu
 function toggleDropdown(container, forcedValue){
   var dropdown = container.getElementsByClassName('dropdown')[0];
