@@ -8,6 +8,8 @@ from appy.shared import utils as sutils
 
 # Messages ---------------------------------------------------------------------
 SSO_NO_PASSWORD = 'No password is stored for a SSO user.'
+U_NO_ACL        = 'User "%s" has no corresponding Zope user.'
+U_DELETED       = 'User "%s" deleted.'
 
 # ------------------------------------------------------------------------------
 class UserWrapper(AbstractWrapper):
@@ -538,8 +540,12 @@ class UserWrapper(AbstractWrapper):
     def onDelete(self):
         '''Before deleting myself, I must delete the corresponding Zope user
            (for local users only).'''
-        if self.source == 'zodb': del self.o.acl_users.data[self.login]
-        self.log('user %s deleted.' % self.login)
+        if self.source == 'zodb':
+            try:
+                del self.o.acl_users.data[self.login]
+            except KeyError:
+                self.log(U_NO_ACL % self.login, type='warning')
+        self.log(U_DELETED % self.login)
         # Call a custom "onDelete" if any
         return self._callCustom('onDelete')
 
