@@ -57,7 +57,7 @@ class AbstractWrapper(object):
            var2="link=not loop.bc.last and bc.view">
          <img if="not loop.bc.first" src=":url('to')"/>
          <!-- Display only the title of the current object -->
-         <span if="not link">::bc.title</span>
+         <span if="not link" class="title">::bc.title</span>
          <!-- Display a link for parent objects -->
          <a if="link" href=":bc.url">:bc.title</a>
         </x>
@@ -1638,11 +1638,12 @@ class AbstractWrapper(object):
             if pt == 'user':
                 users = objs
             else:
-                users = objs[0].users
-                for group in objs[1:]:
+                # Get active users from all retrieved groups
+                users = set()
+                for group in objs:
                     for user in group.users:
-                        if user not in users:
-                            users.append(user)
+                        if user.state == 'active':
+                            users.add(user)
         else:
             # Get all users
             users = self.search('User', noSecurity=True, state='active')
@@ -1675,8 +1676,11 @@ class AbstractWrapper(object):
             # Get the mail recipient for this user
             recipient = user.getMailRecipient()
             if not recipient:
-                user.log('no mail recipient for "%s".' % user.login,
-                         type='warning')
+                # Do not add this user: it does not have e-mail. Log this
+                # problem only if the user is not special.
+                if not user.isSpecial():
+                    user.log('no mail recipient for "%s".' % user.login,
+                             type='warning')
                 continue
             recipients.append(recipient)
         if recipients:
