@@ -1,4 +1,4 @@
-# Copyright (C) 2007-2020 Gaetan Delannay
+# Copyright (C) 2007-2021 Gaetan Delannay
 
 # This file is part of Appy.
 
@@ -57,6 +57,11 @@ configProvider = 'com.sun.star.configuration.ConfigurationProvider'
 configAccess = 'com.sun.star.configuration.ConfigurationAccess'
 configUpdateAccess = 'com.sun.star.configuration.ConfigurationUpdateAccess'
 
+# Default options when exporting to CSV
+defaultCsvOptions = '59,34,76,1'
+# Defaut options when reading a CSV file
+defaultCsvLoadOptions = defaultCsvOptions
+
 # ------------------------------------------------------------------------------
 class ConverterError(Exception): pass
 
@@ -123,6 +128,18 @@ HELP_PDF = 'If the output format is PDF, you can define here conversion ' \
   'options, as a series of comma-separated key=value pairs, as in ' \
   '"ExportNotes=True,PageRange=1-20". Available options are documented in ' \
   '%s.' % HELP_PDF_URL
+HELP_CSV_URL = 'https://wiki.openoffice.org/wiki/Documentation/DevGuide/' \
+  'Spreadsheets/Filter_Options#Filter_Options_for_the_CSV_Filter'
+HELP_CSV = 'If the ouput format is CSV, you can define here conversion ' \
+  'options, as a comma-separated list of values. Default options are: %s.' \
+  'Values correspond to ASCII codes. The first one represents the field ' \
+  'separator. The most frequent values are: 59 (the semi-colon ;), 44 (the ' \
+  'comma ,) and 9 (a tab). The second value represents the text delimiter. ' \
+  'The most frequent values are: 34 (double quotes), 39 (single quotes) or ' \
+  'no value at all (as in 59,,76,1). The third one is the file encoding. The ' \
+  'most frequent values are 76 (UTF-8) and 12 (ISO-8859-1). Complete ' \
+  'documentation about CSV options can be found at %s.' % \
+  (defaultCsvOptions, HELP_CSV_URL)
 
 # ------------------------------------------------------------------------------
 # Classes defined here are used to contact LibreOffice via input/output streams
@@ -244,8 +261,8 @@ class Converter:
     def __init__(self, docPath, result, server=DEFAULT_SERVER,
                  port=DEFAULT_PORT, templatePath=None, optimalColumnWidths=None,
                  distributeColumns=None, script=None, resolveFields=False,
-                 pdfOptions=None, ppp=False, stream='auto', pageStart=1,
-                 verbose=False):
+                 pdfOptions=None, csvOptions=defaultCsvOptions, ppp=False,
+                 stream='auto', pageStart=1, verbose=False):
         # The server and port where LibreOffice listens
         self.server = server
         self.port = port
@@ -288,6 +305,8 @@ class Converter:
             self.functions = {}
         # Options for conversion to PDF
         self.pdfOptions = pdfOptions
+        # Options for conversion to CSV
+        self.csvOptions = csvOptions
         # Verbosity
         self.verbose = verbose
         # Enable the PPP (POD post-processor) ?
@@ -573,9 +592,14 @@ class Converter:
         # Getting some base LO objects is required
         controller = self.doc.getCurrentController()
         viewCursor = controller.getViewCursor()
-        # Force LO to load big documents in their entirery
-        viewCursor.jumpToLastPage()
-        viewCursor.jumpToEndOfPage()
+        # The following lines of code were a trial to force LO to load big
+        # documents in their entirery: because, with some early LO 6.x versions,
+        # it could happen that resulting PDF results were truncated. But in some
+        # rare cases, those lines caused LO to run 100% CPU in an infinite loop.
+        # ~~~
+        # viewCursor.jumpToLastPage()
+        # viewCursor.jumpToEndOfPage()
+        # ~~~
         # 1) Update indexes
         for index in LoIter(self.doc.getDocumentIndexes(), log):
             if index.ServiceName == 'com.sun.star.text.ContentIndex':
@@ -667,8 +691,7 @@ class Converter:
             props = [('Hidden', True)]
             if self.inputType == 'csv':
                 # Give some additional params if we need to open a CSV file
-                props.append(('FilterFlags', '59,34,76,1'))
-                #props.append(('FilterData', 'Any'))
+                props.append(('FilterFlags', defaultCsvLoadOptions))
             self.doc = self.loadDocument(self.docUrl, self.props(props))
             self.log(' done.')
             # [ODT] Perform additional tasks
@@ -706,8 +729,9 @@ class Converter:
            type.'''
         self.log('Saving the result in %s...' % self.resultUrl, cr=False)
         props = [('FilterName', self.resultFilter), ('UpdateDocMode', 3)]
-        if self.resultType == 'csv': # Add options for CSV export
-            props.append(('FilterOptions', '59,34,76,1')) # 59=; 34=" 
+        if self.resultType == 'csv':
+            # Add options for CSV export
+            props.append(('FilterOptions', self.csvOptions))
         elif self.resultType == 'pdf':
             # Get optional PDF options
             options = self.setPdfOptions()
@@ -810,6 +834,8 @@ class ConverterScript:
         add('-v', '--verbose', action='store_true', help=HELP_VERBOSE)
         add('-f', '--pdf', dest='pdf', default=None, metavar='PDF_OPTIONS',
             type='string', help=HELP_PDF)
+        add('-i', '--csv', dest='csv', default=defaultCsvOptions,
+            metavar='CSV_OPTIONS', type='string', help=HELP_CSV)
         add('-c', '--ppp', action='store_true', help=HELP_PPP)
         add('-a', '--stream', dest='stream', default='auto',
             metavar='STREAM', type='string', help=HELP_STREAM)
@@ -833,7 +859,8 @@ class ConverterScript:
         if stream in ('True', 'False'): stream = eval(stream)
         converter = Converter(args[0], args[1], options.server, options.port,
           options.template, optimize, distribute, options.script, resolveFields,
-          pdfOptions, options.ppp, stream, options.pageStart, options.verbose)
+          pdfOptions, options.csv, options.ppp, stream, options.pageStart,
+          options.verbose)
         try:
             converter.run()
         except ConverterError:
