@@ -217,7 +217,7 @@ class PodImporter(DocImporter):
         # Must we communicate with LO via streams ?
         mustStream = (default in (True, 'in')) or \
                      ((default == 'auto') and \
-                      (self.renderer.ooServer != 'localhost'))
+                      (self.renderer.loPool.server != 'localhost'))
         # If the global result must be streamed, for this sub-pod, stream must
         # be "in": this way, the output is written on disk, on the distant LO
         # machine. Then, when we will, via the OdtImporter that will be called
@@ -246,7 +246,7 @@ class PodImporter(DocImporter):
               forceOoCall=self.forceOoCall,
               managePageStyles=self.managePageStyles,
               resolveFields=self.resolveFields, metadata=False,
-              deleteTempFolder=False)
+              deleteTempFolder=False, loPool=r.loPool)
             renderer.stylesManager.stylesMapping = r.stylesManager.stylesMapping
             # Add this renderer to the list of child renderers on the parent
             r.children[template] = renderer
