@@ -20,6 +20,7 @@ import zipfile, shutil, xml.sax, os, os.path, re, mimetypes, time
 
 import appy.pod
 from appy.pod import PodError
+from appy.pod.lo_pool import LoPool
 from appy.shared.zip import unzip, zip
 from appy.pod.buffers import FileBuffer
 from appy.pod import styles_manager as sm
@@ -28,39 +29,25 @@ from appy.pod import doc_importers as imps
 from appy.shared.xml_parser import XmlElement
 from appy.shared import mimeTypes, mimeTypesExts
 from appy.pod.xhtml2odt import Xhtml2OdtConverter
+from appy.shared.utils import FolderDeleter, FileWrapper
 from appy.pod.pod_parser import PodParser, PodEnvironment, OdInsert
-from appy.shared.utils import FolderDeleter, executeCommand, FileWrapper
 
 # ------------------------------------------------------------------------------
-BAD_CONTEXT = 'Context must be either a dict, a UserDict or an instance.'
-RESULT_IS_FOLDER = 'Result file "%s" is a folder, please remove this.'
-RESULT_FILE_EXISTS = 'Result file "%s" exists.'
-CANT_WRITE_TEMP_FOLDER = 'I cannot create temp folder "%s". %s'
-NO_PY_PATH = 'Extension of result file is "%s". In order to perform ' \
-  'conversion from ODT to this format we need to call LibreOffice. But the ' \
-  'Python interpreter which runs the current script does not know UNO, the ' \
-  'library that allows to connect to LibreOffice in server mode. If you ' \
-  'can\'t install UNO in this Python interpreter, you can specify, in ' \
-  'parameter "pythonWithUnoPath", the path to a UNO-enabled Python ' \
-  'interpreter. One such interpreter may be found in ' \
-  '<open_office_path>/program.'
-PY_PATH_NOT_FILE = '"%s" is not a file. You must here specify the absolute ' \
-  'path of a Python interpreter (.../python, .../python.sh, .../python.exe, ' \
-  '.../python.bat...).'
-BAD_RESULT_TYPE = 'Result "%s" has a wrong extension. Allowed extensions ' \
-  'are: "%s".'
-CONVERT_ERROR = 'An error occurred during the conversion. %s'
-BAD_OO_PORT = 'Bad LibreOffice port "%s". Make sure it is an integer.'
-XHTML_ERROR = 'An error occurred while rendering XHTML content.'
-WARNING_INCOMPLETE_OD = 'Warning: your OpenDocument file may not be complete ' \
-  '(ie imported documents may not be present). This is because we could not ' \
-  'connect to LibreOffice in server mode: %s'
-DOC_NOT_SPECIFIED = 'Please specify a document to import, either with a ' \
-  'stream (parameter "content") or with a path (parameter "at").'
-DOC_FORMAT_ERROR = 'POD was unable to deduce the document format. Please ' \
-  'specify it through parameter named "format" (=odt, gif, png, ...).'
-DOC_WRONG_FORMAT = 'Format "%s" is not supported.'
-WARNING_FINALIZE_ERROR = 'Warning: error while calling finalize function. %s'
+BAD_CTX    = 'Context must be either a dict, a UserDict or an instance.'
+R_FOLDER   = 'Result file "%s" is a folder, please remove this.'
+R_EXISTS   = 'Result file "%s" exists.'
+TEMP_F_ERR = 'I cannot create temp folder "%s". %s'
+FMT_KO     = 'Result "%s" has a wrong extension. Allowed extensions are: "%s".'
+CONV_ERR   = 'An error occurred during the conversion. %s'
+NO_LO_POOL = 'For producing pod results of type "%s", LibreOffice must be ' \
+             'called in server mode. Specify its server name and port in ' \
+             'Renderer\'s ad hoc attributes.'
+DOC_KO     = 'Please specify a document to import, either with a stream ' \
+             '(parameter "content") or with a path (parameter "at").'
+DOC_F_ERR  = 'POD was unable to deduce the document format. Please specify ' \
+             'it through parameter named "format" (=odt, gif, png, ...).'
+DOC_F_KO   = 'Format "%s" is not supported.'
+FIN_ERR    = 'Warning: error while calling finalize function. %s'
 
 # Default styles added by pod in content.xml and styles.xml
 POD_STYLES = {}
@@ -134,7 +121,7 @@ class Renderer:
       resolveFields=False, expressionsHolders=defaultExpressionsHolders,
       metadata=True, pdfOptions='ExportNotes=True', csvOptions=None,
       deleteTempFolder=True, protection=False, pageStart=1, tabbedCR=False,
-      fonts=None):
+      fonts=None, loPool=None):
         '''Base on a document template (whose path is in p_template), which is
            an ODT or ODS file containing special expressions and statements
            written in Python, this renderer generates an ODT file (whose path is
@@ -152,8 +139,15 @@ class Renderer:
         # If the Python interpreter which runs the current script is not
         # UNO-enabled, this script will run, in another process, a UNO-enabled
         # Python interpreter (whose path is p_pythonWithUnoPath) which will call
-        # LO. In both cases, we will try to connect to LO in server mode on
-        # p_ooServer:p_ooPort.
+        # LO.
+
+        # When pod needs to communicate with LO, it will assume LO runs on
+        # server named p_ooServer, listening on port p_ooPort. If you run
+        # several LibreOffice servers, p_ooPort may specify a list of ports. In
+        # that case, pod will load-balance requests to the appropriate server.
+        # Note that, when using such a "pool" of LO servers, they all must
+        # reside on the same machine (p_ooServer); pod assumes they are all
+        # up-and-running.
 
         # p_stream dictates the communication between the renderer and LO.
         # ----------------------------------------------------------------------
@@ -320,20 +314,22 @@ class Renderer:
         # like:
         #                      fc-list :lang=en family
 
+        # Please leave p_loPool attribute to None. A LO pool is a data structure
+        # being internal to pod, allowing to communicate with LO. This is only
+        # used by pod itself, when a main Renderer instance needs to create a
+        # sub-Renderer instance, ie, for importing a sub-pod into a main pod.
+
         self.template = template
         self.templateType = self.getTemplateType(template)
         self.result = result
-        self.resultType = os.path.splitext(result)[1].strip('.')
-        self.contentXml = None # Content (string) of content.xml
-        self.stylesXml = None # Content (string) of styles.xml
+        self.resultType  = os.path.splitext(result)[1].strip('.')
+        self.contentXml  = None # Content (string) of content.xml
+        self.stylesXml   = None # Content (string) of styles.xml
         self.manifestXml = None # Content (string) of manifest.xml
-        self.metaXml = None # Content (string) of meta.xml
-        # Manages the styles defined into the ODT template
-        self.tempFolder = None
+        self.metaXml     = None # Content (string) of meta.xml
+        self.tempFolder  = None
         self.env = None
-        self.pythonWithUnoPath = pythonWithUnoPath
-        self.ooServer = ooServer
-        self.ooPort = ooPort
+        self.loPool = loPool or LoPool.get(pythonWithUnoPath, ooServer, ooPort)
         self.stream = stream
         # p_forceOoCall may be forced to True
         self.forceOoCall = forceOoCall or bool(optimalColumnWidths) or \
@@ -405,10 +401,9 @@ class Renderer:
         self.stylesManager.stylesMapping = smap
 
     # Attributes to clone to a sub-renderer when using m_clone hereafter
-    cloneAttributes = ('pythonWithUnoPath', 'ooServer', 'ooPort', 'html',
-      'raiseOnError', 'imageResolver', 'rotateImages', 'stylesTemplate',
-      'optimalColumnWidths', 'distributeColumns', 'expressionsHolders',
-      'protection', 'tabbedCR', 'fonts')
+    cloneAttributes = ('html', 'raiseOnError', 'imageResolver', 'rotateImages',
+      'stylesTemplate', 'optimalColumnWidths', 'distributeColumns',
+      'expressionsHolders', 'protection', 'tabbedCR', 'fonts')
 
     def clone(self, template, context, result, **params):
         '''Creates another Renderer instance, similar to p_self, but for
@@ -445,7 +440,7 @@ class Renderer:
         elif isinstance(context, dict) or isinstance(context, UserDict):
             r.update(context)
         else:
-            raise PodError(BAD_CONTEXT)
+            raise PodError(BAD_CTX)
         # Incorporate the default, unalterable, context
         r.update({'xhtml': self.renderXhtml, 'text': self.renderText,
           'document': self.importDocument, 'image': self.importImage,
@@ -618,7 +613,7 @@ class Renderer:
 
         importer = None
         # Is there someting to import ?
-        if not content and not at: raise PodError(DOC_NOT_SPECIFIED)
+        if not content and not at: raise PodError(DOC_KO)
         # Convert Zope files into Appy wrappers
         if content.__class__.__name__ in ('File', 'Image'):
             content = FileWrapper(content)
@@ -628,7 +623,7 @@ class Renderer:
         if not format:
             # It should be deduced from p_at
             if not at:
-                raise PodError(DOC_FORMAT_ERROR)
+                raise PodError(DOC_F_ERR)
             format = os.path.splitext(at)[1][1:]
         else:
             # If format is a mimeType, convert it to an extension
@@ -649,7 +644,7 @@ class Renderer:
         elif format in self.convertibleFormats:
             importer = imps.ConvertImporter
         else:
-            raise PodError(DOC_WRONG_FORMAT % format)
+            raise PodError(DOC_F_KO % format)
         imp = importer(content, at, format, self)
         # Initialise image-specific parameters
         if isImage:
@@ -701,7 +696,7 @@ class Renderer:
 
         # Is there a pod template defined ?
         if not content and not at:
-            raise PodError(DOC_NOT_SPECIFIED)
+            raise PodError(DOC_KO)
         # If the POD template is specified as a Zope file, convert it into a
         # Appy FileWrapper.
         if content.__class__.__name__ == 'File':
@@ -759,10 +754,10 @@ class Renderer:
         self.result = os.path.abspath(self.result)
         # Raise an error if the result already exists and we can't overwrite it
         if os.path.isdir(self.result):
-            raise PodError(RESULT_IS_FOLDER % self.result)
+            raise PodError(R_FOLDER % self.result)
         exists = os.path.isfile(self.result)
         if not self.overwriteExisting and exists:
-            raise PodError(RESULT_FILE_EXISTS % self.result)
+            raise PodError(R_EXISTS % self.result)
         # Remove the result if it exists
         if exists: os.remove(self.result)
         # Create a temp folder for storing temporary files
@@ -770,7 +765,7 @@ class Renderer:
         try:
             os.mkdir(self.tempFolder)
         except OSError, oe:
-            raise PodError(CANT_WRITE_TEMP_FOLDER % (self.result, oe))
+            raise PodError(TEMP_F_ERR % (self.result, oe))
         # The "unzip" folder is a sub-folder, within self.tempFolder, where
         # p_self.template will be unzipped.
         self.unzipFolder = os.path.join(self.tempFolder, 'unzip')
@@ -868,92 +863,6 @@ class Renderer:
                 FolderDeleter.delete(self.tempFolder)
             raise po
 
-    def callLibreOffice(self, resultName, outputName=None, format=None):
-        '''Call LibreOffice in server mode to convert or update the result'''
-        # Here are the valid combinations for parameter's values.
-        # ----------------------------------------------------------------------
-        # no outputName | The converter will produce a result whose name is
-        #   no format   | p_resultName whose file extension has been replaced
-        #               | with the one specified in self.resultType.
-        # ----------------------------------------------------------------------
-        # no outputName | Idem, but the output format is forced to p_format
-        #    format     | instead of using self.resultType.
-        # ----------------------------------------------------------------------
-        #  outputName   | The converter will produce a result whose name is
-        #  no format    | p_outputName. The output format will depend on
-        #               | p_outputName's file extension.
-        # ----------------------------------------------------------------------
-        loOutput = ''
-        # Determine the "result" to ask to LibreOffice
-        if outputName:
-            result = outputName
-            resultType = os.path.splitext(result)[-1][1:]
-        else:
-            result = format or self.resultType
-            resultType = result
-        # Get CSV options if we must produce a CSV file
-        if resultType == 'csv':
-            csvOptions = (self.csvOptions or CsvOptions.default).asString()
-        else:
-            csvOptions = None
-        try:
-            if (not isinstance(self.ooPort, int)) and \
-               (not isinstance(self.ooPort, long)):
-                raise PodError(BAD_OO_PORT % str(self.ooPort))
-            try:
-                from appy.pod.converter import Converter, ConverterError
-                try:
-                    Converter(resultName, result, self.ooServer, self.ooPort,
-                      self.stylesTemplate, self.optimalColumnWidths,
-                      self.distributeColumns, self.script, self.resolveFields,
-                      self.pdfOptions, csvOptions, self.ppp, self.stream,
-                      self.pageStart).run()
-                except ConverterError, ce:
-                    raise PodError(CONVERT_ERROR % str(ce))
-            except ImportError:
-                # I do not have UNO. So try to launch a UNO-enabled Python
-                # interpreter which should be in self.pythonWithUnoPath.
-                pyPath = self.pythonWithUnoPath
-                if not pyPath:
-                    raise PodError(NO_PY_PATH % resultType)
-                if not os.path.isfile(pyPath):
-                    raise PodError(PY_PATH_NOT_FILE % pyPath)
-                convScript = '%s/converter.py' % \
-                             os.path.dirname(appy.pod.__file__)
-                cmd = [pyPath, convScript, resultName, result,
-                       '-e', self.ooServer, '-p', str(self.ooPort)]
-                add = cmd.append
-                if self.stylesTemplate:
-                    add('-t'); add(self.stylesTemplate)
-                if self.optimalColumnWidths:
-                    add('-o'); add(str(self.optimalColumnWidths))
-                if self.distributeColumns:
-                    add('-d'); add(str(self.distributeColumns))
-                if self.script:
-                    add('-s'); add(self.script)
-                if self.resolveFields:
-                    add('-r'); add(self.resolveFields)
-                if self.pdfOptions:
-                    add('-f'); add(self.pdfOptions)
-                if csvOptions:
-                    add('-i'); add(csvOptions)
-                if self.ppp: add('-c')
-                if self.stream != 'auto':
-                    add('-a'); add(str(self.stream))
-                if self.pageStart > 1:
-                    add('-g'); add(str(self.pageStart))
-                out, loOutput = executeCommand(cmd)
-        except PodError, pe:
-            # When trying to call LO in server mode for producing ODT or ODS
-            # (=forceOoCall=True), if an error occurs we have nevertheless
-            # an ODT or ODS to return to the user. So we produce a warning
-            # instead of raising an error.
-            if (resultType in self.templateTypes) and self.forceOoCall:
-                print(WARNING_INCOMPLETE_OD % str(pe))
-            else:
-                raise pe
-        return loOutput
-
     def getTemplateType(self, template):
         '''Identifies the type of this POD p_template (ods or odt). If
            p_template is a string, it is a file name: simply get its extension.
@@ -972,6 +881,12 @@ class Renderer:
                 r = 'odt' # We suppose this is ODT
         return r
 
+    def callLibreOffice(self, resultName, format=None, outputName=None):
+        '''Call LibreOffice in server mode to convert or update the result'''
+        if self.loPool is None:
+            raise PodError(NO_LO_POOL % resultType)
+        return self.loPool(self, resultName, format, outputName)
+
     def finalize(self):
         '''Re-zip the result and potentially call LibreOffice if target format
            is not among self.templateTypes or if forceOoCall is True.'''
@@ -1012,22 +927,21 @@ class Renderer:
             try:
                 for fun in self.finalizeFunction: fun(self.unzipFolder, self)
             except Exception, e:
-                print(WARNING_FINALIZE_ERROR % str(e))
+                print(FIN_ERR % str(e))
         # Re-zip the result, first as an OpenDocument file of the same type as
         # the POD template (odt, ods...)
         resultName = os.path.join(self.tempFolder,
                                   'result.%s' % self.templateType)
         resultType = self.resultType
         zip(resultName, self.unzipFolder, odf=True)
-        if (resultType in self.templateTypes) and not self.forceOoCall:
+        if resultType in self.templateTypes and not self.forceOoCall:
             # Simply move the ODT result to the result
             os.rename(resultName, self.result)
         else:
             if resultType not in FILE_TYPES:
-                raise PodError(BAD_RESULT_TYPE % (
-                    self.result, FILE_TYPES.keys()))
+                raise PodError(FMT_KO % (self.result, FILE_TYPES.keys()))
             # Call LibreOffice to perform the conversion or document update
-            output = self.callLibreOffice(resultName, self.result)
+            output = self.callLibreOffice(resultName, outputName=self.result)
             # I (should) have the result in self.result
             if not os.path.exists(self.result):
                 if resultType in self.templateTypes:
@@ -1036,5 +950,5 @@ class Renderer:
                     # "raw" pod result that exists in "resultName".
                     os.rename(resultName, self.result)
                 else:
-                    raise PodError(CONVERT_ERROR % output)
+                    raise PodError(CONV_ERR % output)
 # ------------------------------------------------------------------------------
