@@ -1024,6 +1024,13 @@ class StylesGenerator:
         '''Adds the style definition dynamic styles'''
         self.stylesManager.dynamicStyles.add(target, style)
 
+    def addStyleInstance(self, name):
+        '''Add the style named p_name to the style manager's defined styles, as
+           a Style instance.'''
+        styles = self.stylesManager.styles
+        if name not in styles:
+            styles[name] = Style(name, 'paragraph')
+
     def addGraphicalStyle(self, target, **kwargs):
         '''Creates and add a style of type "graphic" within the dynamically
            generated styles.'''
@@ -1106,7 +1113,10 @@ class StylesGenerator:
     def get_any(self, xhtmlElem, odfAttrs, baseStyle, add=False):
         '''Generates a paragraph style'''
         createNew, styleName = self.getStyleName(xhtmlElem, odfAttrs, baseStyle)
-        if not createNew: return styleName
+        if not createNew:
+            # Manage p_add being True (see comment below)
+            if add: self.addStyleInstance(styleName)
+            return styleName
         # Generate a new style. Is there a parent style ?
         baseStyle = baseStyle or self.defaultParents.get(xhtmlElem.elem)
         names = [name for name, value in odfAttrs]
@@ -1138,10 +1148,7 @@ class StylesGenerator:
         # If p_add is True, also add the style to styleManager's defined styles
         # (as a Style instance). Else, it won't be found when it will need to be
         # applied on an inner paragraph.
-        if add:
-            styles = self.stylesManager.styles
-            if styleName not in styles:
-                styles[styleName] = Style(styleName, 'paragraph')
+        if add: self.addStyleInstance(styleName)
         return styleName
 
     def get_td(self, xhtmlElem, odfAttrs, baseStyle):
