@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (C) 2007-2020 Gaetan Delannay
+# Copyright (C) 2007-2021 Gaetan Delannay
 
 # This file is part of Appy.
 
@@ -20,12 +20,11 @@
 import re, xml.sax, math
 
 from appy.pod import *
-from appy.pod.doc_importers import getUuid
 from appy.pod.odf_parser import OdfEnvironment
 from appy.shared.css import CssStyles, CssValue, px2cm
 from appy.shared.xml_parser import XmlEnvironment, XmlParser, Escape
 from appy.shared.utils import WhitespaceCruncher, formatNumber, addPair
-from appy.pod.styles_manager import Style, BulletedProperties,NumberedProperties
+from appy.pod.styles_manager import Style,BulletedProperties,NumberedProperties
 
 # Tags for which there is a direct correspondance between HTML and ODF
 h = 'text:h'
@@ -741,7 +740,7 @@ class XhtmlEnvironment(XmlEnvironment):
     def getUniqueStyleName(self, type):
         '''Gets a unique name for an element of some p_type (a table, a
            list).'''
-        return '%s%s' % (type.capitalize(), getUuid(removeDots=True))
+        return getUuid(removeDots=True, prefix=type.capitalize())
 
     def getCurrentElement(self, isList=False):
         '''Gets the element that is on the top of self.currentElements or
@@ -819,12 +818,8 @@ class XhtmlEnvironment(XmlEnvironment):
             # Manage cells' borders
             border = table.props.border
             if border is None:
-                border = table.border
-                if not border:
-                    xhtmlElem.cssStyles.add('border', '0')
-                # Else, the default will be "1"
-            else:
-                xhtmlElem.cssStyles.add('border', border)
+                border = table.border and '0.05pt solid #000000' or '0'
+            xhtmlElem.cssStyles.add('border', border)
             # Manage cells' spacing
             spacing = table.borderSpacing
             if spacing:
@@ -837,7 +832,8 @@ class XhtmlEnvironment(XmlEnvironment):
                (xhtmlElem.elem in PARA_TAGS):
                 # The enclosed "p" must get the td's inner styles
                 if parent.innerStyle:
-                    xhtmlElem.cssStyles.addClass(parent.innerStyle)
+                    xhtmlElem.cssStyles.addClass(parent.innerStyle,
+                                                 append=False)
                 if parent.innerCssStyles:
                     xhtmlElem.cssStyles.merge(parent.innerCssStyles)
         # Get the base ODF style for this p_xhtmlElem
