@@ -1,4 +1,4 @@
-# Copyright (C) 2007-2020 Gaetan Delannay
+# Copyright (C) 2007-2021 Gaetan Delannay
 
 # This file is part of Appy.
 
@@ -261,8 +261,13 @@ class Merger:
 class HtmlDiff:
     '''This class allows to compute differences between two versions of some
        HTML chunk.'''
-    insertStyle = 'color: blue; cursor: help'
-    deleteStyle = 'color: red; text-decoration: line-through; cursor: help'
+
+    # Default CSS styles to apply on a insertion or a deletion
+    insertStyle = 'color:blue; cursor:help'
+    deleteStyle = 'color:red; text-decoration:line-through; cursor:help'
+
+    # Template tag that wraps a diff, be it a deletion or an insertion
+    templateDiv = '<div style="%s" title="%s">%s</div>'
 
     def __init__(self, old, new,
                  insertMsg=u'Inserted text', deleteMsg=u'Deleted text',
@@ -316,7 +321,7 @@ class HtmlDiff:
 
            If p_msg is given, it will be used instead of the default
            p_type-related message stored on p_self.'''
-        # Will the surrouding tag be a div or a span?
+        # Will the surrounding tag be a div or a span?
         if sep == '\n': tag = 'div'
         else: tag = 'span'
         # What message will it show in its 'title' attribute?
