@@ -30,9 +30,9 @@ LDAP_CONNECT_KO = 'Could not connect to %s (%s).'
 LDAP_COUNTS     = '%d local active SSO users // %d LDAP users'
 LDAP_ACT        = '%d user(s) %sactivated: %s.'
 LDAP_NO_DEACT   = 'No user was deactivated.'
-SYNC_SUMMARY    = 'users synchronization: %d local user(s) created, %d ' \
-                  'updated, %d untouched and %d invalid entries. %s local ' \
-                  'user(s) deactivated and %d reactivated.'
+SYNC_SUMMARY    = 'users sync from %s: %d local user(s) created, %d updated, ' \
+                  '%d untouched and %d invalid entries. %s local user(s) ' \
+                  'deactivated and %d reactivated.'
 
 # ------------------------------------------------------------------------------
 class LdapConfig:
@@ -324,7 +324,7 @@ class LdapConfig:
         if reactivated:
             log(LDAP_ACT % (counts.reactivated, 're', ', '.join(reactivated)))
 
-    def synchronizeUsers(self, tool, sso=None):
+    def synchronizeUsers(self, tool, sso=None, log=True):
         '''Synchronizes the local User copies with this LDAP user base. Returns
            a message with details about the operation.'''
         # If this LDAP config is part of a SSO config, this latter is available
@@ -333,7 +333,7 @@ class LdapConfig:
         if not self.enabled: raise Exception(LDAP_DISABLED)
         # Get a connector to the LDAP server and connect to the LDAP server
         serverUri = self.getServerUri()
-        tool.log('reading users from %s...' % serverUri)
+        if log: tool.log('reading users from %s...' % serverUri)
         connector = LdapConnector(serverUri, tool=tool)
         success, msg = connector.connect(self.adminLogin, self.adminPassword)
         if not success: raise Exception(LDAP_CONNECT_KO % (serverUri, msg))
@@ -375,10 +375,10 @@ class LdapConfig:
         # Activate or deactivate users
         self.updateUserStates(tool, ldapUsers, counts, sso=sso)
         # Log the operation and return a message
-        message = SYNC_SUMMARY % (counts.created, counts.updated,
+        message = SYNC_SUMMARY % (serverUri, counts.created, counts.updated,
                                   counts.untouched, counts.wrong,
                                   counts.deactivated, counts.reactivated) 
-        tool.log(message)
+        if log: tool.log(message)
         return message
 
 # ------------------------------------------------------------------------------
