@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2007-2020 Gaetan Delannay
+# Copyright (C) 2007-2021 Gaetan Delannay
 
 # This file is part of Appy.
 
@@ -86,10 +86,11 @@ class Escape:
     rexBlanksApos = re.compile("[%s'%s]" % (chars, blanks))
     # All regular expressions, grouped by flavour and 'apos' escaping or not
     nonXmlRex = { False: rexBlanks, True: rexBlanksApos }
-    rexAll = {'xml': { False: rex, True: rexApos },
-              'odf': nonXmlRex,
-              'odf*': nonXmlRex,
-              'xhtml': nonXmlRex }
+    rexAll = {'xml'   : { False: rex, True: rexApos },
+              'odf'   : nonXmlRex,
+              'odf*'  : nonXmlRex,
+              'xhtml' : nonXmlRex,
+              'xhtml*': nonXmlRex}
     # Entities to use to escape base chars
     entities = {'<':'&lt;', '>':'&gt;', '&':'&amp;', '"':'&quot;', "'":'&apos;'}
     # For "odf" and "xhtml" flavours, we replace "blank" chars with their
@@ -102,6 +103,7 @@ class Escape:
      'odf': {'\n':'<text:line-break/>', '\t':'<text:tab/>', '\r':''},
      'odf*':{'\n':'<text:tab/><text:line-break/>', '\t':'<text:tab/>', '\r':''},
      'xhtml': {'\n':'<br/>', '\t':'', '\r':''},
+     'xhtml*': {'\n':'</p><p>', '\t':'', '\r':''},
      'xml': {} # We do not escape blanks by default
     }
     # Complete "values" with entities
@@ -125,9 +127,14 @@ class Escape:
         return rex.sub(fun, s)
 
     @staticmethod
-    def xhtml(s):
+    def xhtml(s, p=False):
         '''Shorthand for escaping XHTML content'''
-        return Escape.xml(s, flavour='xhtml')
+        # If p_p is False, \n are replaced with <br/> tags. Else, every
+        # encountered \n leads to the creation of a new paragraph, surrounded by
+        # <p></p>.
+        suffix = p and '*' or ''
+        r = Escape.xml(s, flavour='xhtml%s' % suffix)
+        return p and ('<p>%s</p>' % r) or r
 
 # ------------------------------------------------------------------------------
 class XmlElement:
