@@ -78,8 +78,9 @@ class Config:
     # Place here a appy.deploy.Config instance defining how to deploy this app
     # on distant servers.
     deploy = None
-    # When using Google analytics, specify here the Analytics ID
-    googleAnalyticsId = None
+    # In order to enable Google Analytics on your app, place here an instance of
+    # appy.utils.analytics.Analytics.
+    analytics = None
     # When using Ogone, place an instance of appy.model.fields.ogone.Config in
     # the field below.
     ogone = None
