@@ -137,13 +137,6 @@ App(Path('.')).update()
 #- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 '''
 
-# <app>/static/robots.txt
-appRobots = '''
-# More information about this file on http://robots-txt.com
-User-agent: *
-Disallow: /
-'''
-
 # <ext>/__init__.py
 extInit = '''
 #- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -263,16 +256,6 @@ class App(Target):
       'static' # Stores any static content (images, CSS or Javascript files...)
     )
 
-    # Mandatory files to have in <appFolder>/static
-    files = (
-      # The icon retrieved by Safari
-      'appleicon.png',
-      # he icon retrieved by other browsers
-      'favicon.ico',
-      # The file read by robots
-      'robots.txt'
-    )
-
     def __init__(self, folder):
         # The base folder for the app. Ensure it is absolute.
         if not folder.is_absolute():
@@ -292,24 +275,13 @@ class App(Target):
         # Create base folders
         for name in App.subFolders:
             folder = self.folder / name
-            if not folder.exists(): folder.mkdir()
-            if name == 'static':
-                # Ensure mandatory files are present and create them if not
-                robots = folder / 'robots.txt' # The file read by robots
-                if not robots.exists():
-                    self.createFile(robots, appRobots)
-                # The icon retrieved by browsers, shown besides the address bar
-                for name in ('favicon.ico', 'appleicon.png'):
-                    icon = folder / name
-                    if not icon.exists():
-                        # Copy the default one in Appy
-                        ico = '%s/ui/static/%s' % (str(appy.path), name)
-                        shutil.copy(ico, str(icon))
+            if not folder.exists():
+                folder.mkdir()
 
     def update(self):
         '''Updates an existing app'''
         print('Updating %s...' % self.folder)
-        # Ensure the base files and folders are created
+        # Ensure the base folders are created
         self.create()
         # Call the translations updater that will create or update translation
         # files for this app.
@@ -364,7 +336,7 @@ class Make(Program):
     allowedTargets = ('app', 'site', 'ext')
 
     # Help messages
-    APP_S        = 'url=<url>, [name=<name>,login=<login>, password=<password>]'
+    APP_S        = 'url=<url>,[name=<name>,login=<login>,password=<password>]'
     HELP_TARGET  = 'can be "app" for creating/updating an app, "site" for ' \
                    'creating a site or "ext" for creating an extension to an ' \
                    'app.'
