@@ -2,7 +2,7 @@
    of a given class from an Appy app's model.'''
 
 #- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-# Copyright (C) 2007-2020 Gaetan Delannay
+# Copyright (C) 2007-2021 Gaetan Delannay
 
 # This file is part of Appy.
 
@@ -138,7 +138,8 @@ class Catalog(PersistentMapping):
             for className, indexes in populate.items():
                 for index in indexes:
                     names.append('%s::%s' % (className, index.name))
-            message = IDXS_POP % (counts.updated, counts.total, names)
+            message = IDXS_POP % (counts.updated, counts.total,
+                                  ', '.join(names))
             handler.log('app', 'info', message)
         if counts.lost:
             message = IDXS_CLEAN % len(counts.lost)
