@@ -34,6 +34,7 @@ from appy.database.catalog import Catalog
 from appy.xml.marshaller import Marshaller
 from appy.model.fields.string import String
 from appy.model.fields.action import Action
+from appy.model.fields.python import Python
 from appy.model.fields.computed import Computed
 from appy.model.workflow.history import History
 from appy.model.fields.phase import Page, UiPhases
@@ -57,11 +58,12 @@ NO_STR      = 'Specify the name of the class as a string.'
 class Base:
     '''Base class for any Appy class'''
 
-    # Some elements will be traversed
-    traverse = {'history': True}
-
     # Make some elements available here
     Lock = Lock
+    Search = Search
+
+    # Some elements will be traversed
+    traverse = {'history': True, 'Search': True}
 
     # The default workflow for a class that does not define one
     workflow = workflows.Anonymous
@@ -155,6 +157,15 @@ class Base:
 
     record = Computed(**recordAttributes)
 
+    #- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+    # Python interpreter
+    #- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+
+    interpreter = Python(label='Base', layouts='f',
+      page=Page('python', label='Base_page_python', sticky=True,
+                show=lambda o: 'view' if o.user.login == 'admin' else None,
+                icon='python.svg'))
+
     #- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
     # Properties
     #- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -300,7 +311,12 @@ class Base:
 
     def goto(self, url=None, message=None):
         '''Return to some p_url or to the referer page'''
-        return self.resp.goto(url, message)
+        self.resp.goto(url, message)
+
+    def gotoSet(self):
+        '''Return True if m_goto has already been called and the response code
+           is already a 303 "Redirect".'''
+        return self.resp.code == 303
 
     #- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
     # Security methods
@@ -340,9 +356,19 @@ class Base:
            the field on this class instead of on p_self's class. If p_raiseError
            is True and the field is not found, an exception is raised. Else,
            None is returned.'''
+        # The field with this p_name may be an inner field within an outer field
+        isInner = '*' in name
+        if isInner:
+            parts = name.split('*')
+            if len(parts) == 2: name, sub = parts
+            else:               name, sub, i = parts
+        # Get the class where the field definition may be found
         class_ = self.H().server.model.classes[className] if className \
                                                           else self.getClass()
         r = class_.fields.get(name)
+        # Get the sub-field when relevant
+        if r and isInner: r = r.getField(sub)
+        # Raise an error if the field was not found and p_raiseError is True
         if r is None and raiseError:
             raise AttributeError(FIELD_KO % (name, class_.name))
         return r
@@ -741,7 +767,7 @@ class Base:
        <img if="not loop.part.first" src=":url('arrowsA.svg')"
             class="iconS" style="transform: rotate(270deg)"/>
        <!-- Display the title or a link to the object -->
-       <span if="not link">::part.title</span>
+       <span if="not link" class="title">::part.title</span>
        <!-- Display a link for parent objects -->
        <a if="link" href=":part.url">::part.title</a>
       </x>
@@ -781,7 +807,8 @@ class Base:
       <!-- Standard actions -->
 
       <!-- Save -->
-      <div if="isEdit and current.showSave" var2="label=_('object_save')">
+      <div if="isEdit and current.showSave"
+           var2="label=o.class_.getSaveText(o)">
        <div>
         <a class="clickable"
            onclick=":'submitAppyForm(%s,%s,%s)' % \
@@ -1032,7 +1059,7 @@ class Base:
     # The object, as shown in a list of referred (tied) objects
     pxTied = Px('''
      <tr var="ifield=initiator.field;
-              *=ifield.initPx(initiator.o, req, _ctx_) if _ctx_.ajaxSingle \
+              *=ifield.initPx(initiator.o, req, _ctx_) if _ctx_.ajaxSingle
                                                        else None;
               id=o.iid;
               objectIndex=ifield.getIndexOf(initiator.o, o, raiseError=False);
@@ -1250,6 +1277,7 @@ class Base:
         # If we are in a popup, render a minimalist HTML page that will close it
         if popup: return Iframe.goBack(self.tool, initiator)
         # Determine, if not defined yet, the URL to go back to
+        if self.gotoSet(): return
         if not url:
             if initiator:
                 # Go back to the initiator page
@@ -1291,19 +1319,23 @@ class Base:
         # If p_self has already been deleted ("text" being None in that case),
         # or if the logged user has lost the right to view it, redirect him to
         # its home page.
-        if (text is None) or not guard.mayView(self):
+        if text is None or not guard.mayView(self):
             if popup:
                 if text: self.say(text)
                 return Iframe.goBack(tool, initiator)
-            else:
-                return self.goto(tool.computeHomePage(), message=text)
+            elif not self.gotoSet():
+                self.goto(tool.computeHomePage(), message=text)
+            return
         # If we are here, action is "save" and p_self has been updated. Redirect
         # the user to the appropriate page.
         self.say(text)
         # Come back from the popup if we were in it
-        if popup and (req.gotoLayout == 'view'):
+        if popup and req.gotoLayout == 'view':
             return Iframe.goBack(tool, initiator)
-        elif isTemp and initiator:
+        # Go to wherever has been defined, if already defined
+        if self.gotoSet(): return
+        # Go to the appropriate URL
+        if isTemp and initiator:
             # Let the initiator choose the back URL
             url = initiator.getBackUrl(self)
         else:
@@ -1311,7 +1343,7 @@ class Base:
             # "gotoLayout".
             url = self.getUrl(sub=req.gotoLayout, page=req.gotoPage,
                               nav=req.nav or 'no')
-        return self.goto(url)
+        self.goto(url)
 
     traverse['new'] = True
     def new(self):
@@ -1361,6 +1393,7 @@ class Base:
         text = self.delete(historize=True)
         # Prepare the back URL. None = the default = the referer page.
         back = None
+        gotoSet = self.gotoSet()
         # Return a message to the UI
         handler = self.H()
         if not text:
@@ -1368,12 +1401,13 @@ class Base:
             text = self.translate('action_done')
             # If we were consulting the object itself, return to the home page.
             # Else, return to the referer page (it is the default).
-            if handler.isPublished(self):
+            if not gotoSet and handler.isPublished(self):
                 back = self.tool.computeHomePage()
         # If we are called from an Ajax request, simply return the message
         if handler.isAjax(): return text
-        # Go to the "back" URL
-        return self.goto(url=back, message=text)
+        # Go to the "back" URL (if "goto" hasn't been called yet)
+        if not gotoSet:
+            self.goto(url=back, message=text)
 
     traverse['unlock'] = 'perm:write'
     def unlock(self):
