@@ -1,5 +1,5 @@
 #- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-# Copyright (C) 2007-2020 Gaetan Delannay
+# Copyright (C) 2007-2021 Gaetan Delannay
 
 # This file is part of Appy.
 
@@ -54,7 +54,7 @@ class Batch:
     pxGotoNumber = Px('''
      <x var2="label=_('goto_number');
               gotoName='%d_%s_goto' % (o.iid, field.name)">
-      <span class="discreet" style="padding-left: 5px">:label</span> 
+      <span style="padding-left: 5px">:label</span>
       <input type="text" size=":len(str(total)) or 1" onclick="this.select()"
              onkeydown=":'if (event.keyCode==13) document.getElementById' \
                          '(%s).click()' % q(gotoName)"/><img
