@@ -60,7 +60,7 @@ class Show:
     # already shown as a part of some custom widget.
     V_ = ('edit', 'result', 'xml')
     # All layouts but view and edit. To use when you need both E_ and V_.
-    VE_ = ('result', 'xml')
+    RX = VE_ = ('result', 'xml')
     # This set is used for showing workflow transitions in lists of objects
     TR = ('view', 'result')
     # This is, a.o., for custom widgets whose edit and view variants are not
@@ -394,8 +394,8 @@ class Field:
       <!-- Pressing the "enter" key in the field clicks the icon (onkeydown) -->
       <input type="text" size="7" id=":filterId"
              value=":mode.filters.get(name, '')"
-             onkeydown=":'if (event.keyCode==13) document.getElementById ' \
-                         '(%s).click()' % q(filterIdIcon)"/>
+             onkeydown=":'if (event.keyCode==13) document.getElementById(%s).
+                          click()' % q(filterIdIcon)"/>
       <img id=":filterIdIcon" class="clickable iconS" src=":url('funnel.svg')"
            onclick=":'askBunchFiltered(%s,%s)' % (q(mode.hook), q(name))"/>
      </x>''')
@@ -828,6 +828,9 @@ class Field:
            request value is searched within the outer value build and stored on
            the request.'''
         if self.isInner():
+            # An inner field. In that case, p_name contains the row index.
+            # Without it, it is impossible to get the value.
+            if name is None: return
             # p_self is a sub-field into an outer field: p_name is of the form
             #            [outerName]*[name]*[rowId]
             outerName, name, rowId = name.split('*')
@@ -1147,7 +1150,7 @@ class Field:
            for string multilingual fields.'''
         return (name or self.name) in req
 
-    def getStorableValue(self, o, value, complete=False):
+    def getStorableValue(self, o, value, single=False):
         '''p_value is a valid value initially computed through calling
            m_getRequestValue. So, it is a valid representation of the field
            value coming from the request. This method computes the value
@@ -1155,12 +1158,9 @@ class Field:
            stored in the database.'''
         # More precisely, m_getStorableValue computes a value that can be used
         # as input for m_store. But this latter can further transform it. For
-        # example, a value produced by p_getStorableValue for a Ref field can be
-        # a list of object IDs; method Ref.store will then convert it to a list
-        # of objects and make cross-links between them and p_obj. If p_complete
-        # is True, the value produced will be forced to be as close as possible
-        # as the database value. In our Ref example, it will be a list of
-        # objects (but cross-links will not be established).
+        # example, a value produced by p_getStorableValue for a Ref field is a
+        # list of objects; method Ref.store will then go further and make
+        # cross-links between them and p_obj.
         if self.isEmptyValue(o, value): return
         return value
 
@@ -1289,8 +1289,8 @@ class Field:
         message = self.validateValue(o, value)
         if message: return message
         # Evaluate the custom validator if one has been specified
-        value = self.getStorableValue(o, value)
-        if self.validator and (type(self.validator) in self.validatorTypes):
+        if self.validator and type(self.validator) in self.validatorTypes:
+            value = self.getStorableValue(o, value)
             if type(self.validator) != self.validatorTypes[-1]:
                 # It is a custom function: execute it
                 try:
@@ -1486,13 +1486,13 @@ class Field:
         # Height
         height = getattr(self, '%sheight' % prefix)
         if isMultiple and isinstance(height, str):
-            res.append('height: %s' % height)
+            res.append('height:%s' % height)
             # If height is an integer value, it will be dumped in attribute
             # "size", not in CSS attribute "height".
         # Width
         width = getattr(self, '%swidth' % prefix)
         if isinstance(width, str):
-            res.append('width: %s' % width)
+            res.append('width:%s' % width)
             # If width is an integer value, it represents a number of chars
             # (usable for truncating the shown values), not a width for the CSS
             # attribute.
