@@ -82,7 +82,7 @@ class Action(Field):
 
     # PX for viewing the Action button
     view = cell = query = Px('''
-     <form var="isFake=field.isFake(o, _);
+     <form var="isFake=field.isFake(o, _);  
                 formId='%d_%s_form' % (o.iid, name);
                 label=_(field.labelId);
                 multi=multi|False;
@@ -264,7 +264,7 @@ class Action(Field):
         #    | order to clearly identify this little cheat, name this first arg
         #    | "tool" instead of "self".
         # ----------------------------------------------------------------------
-        #  2 | Defining an action field on the 'query' layout, as explained in
+        #  2 | Defining an action field on the "query" layout, as explained in
         #    | the previous step, prevents the field from being shown on the
         #    | standard object's layouts, but does not automatically display the
         #    | action on search results from all searches defined in your class.
@@ -357,7 +357,12 @@ class Action(Field):
         # Determine the back hook and check hook (if multi)
         if multi:
             back = 'searchResults'
-            check = q(req['search'])
+            check = req.search
+            if ',' in check:
+                # This is a search being embedded into another field. In that
+                # case, the hook is simply 'search'.
+                check = 'search'
+            check = q(check)
         else:
             back = str(o.iid) if layout == 'cell' else None
             check = 'null'
