@@ -164,7 +164,8 @@ class Boolean(Field):
         base = Field.getOnChange(self, o, layout, className=className)
         return '%s; %s' % (r, base) if base else r
 
-    def getStorableValue(self, o, value, complete=False):
+    def getStorableValue(self, o, value, single=False):
+        '''Converts this string p_value to a boolean value'''
         if not self.isEmptyValue(o, value):
             r = eval(value)
             return r
