@@ -160,7 +160,7 @@ class Computed(Field):
         traversal = o.traversal
         existingContext = traversal.context
         context = traversal.createContext()
-        r = context.uiSearch.pxResult(context)
+        r = context.uiSearch.search.innerResults(context)
         # Reinitialise the context correctly
         if existingContext:
             traversal.context = existingContext
