@@ -291,7 +291,8 @@ class Date(Field):
 
     def getRequestSuffix(self): return '_year'
 
-    def getStorableValue(self, o, value, complete=False):
+    def getStorableValue(self, o, value, single=False):
+        '''Converts this string p_value too a DateTime instance'''
         if not self.isEmptyValue(o, value):
             return DateTime(value)
 
