@@ -37,7 +37,7 @@ from appy.xml.unmarshaller import UnmarshalledFile
 BAD_FTUPLE = 'This is not the way to set a file. You can specify a 2-tuple ' \
              '(fileName, fileContent) or a 3-tuple (fileName, fileContent, ' \
              'mimeType).'
-CONV_ERR   = 'An error occurred. %s'
+CONV_ERR   = 'Pod::Converter error. %s'
 PATH_KO    = 'Missing absolute disk path for %s.'
 RESIZED    = '%s resized to %spx.'
 
@@ -258,7 +258,11 @@ class FileInfo:
         shutil.copyfile(self.getFilePath(o), filePath)
         if format:
             # Convert the dumped file using LibreOffice
-            out, err = Converter(filePath, format).run()
+            try:
+                Converter(filePath, format).run()
+            except Converter.Error as err:
+                o.log(CONV_ERR % str(err), type='error')
+                return
             # Even if we have an "error" message, it could be a simple warning.
             # So we will continue here and, as a subsequent check for knowing if
             # an error occurred or not, we will test the existence of the
