@@ -1,5 +1,5 @@
 #- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-# Copyright (C) 2007-2020 Gaetan Delannay
+# Copyright (C) 2007-2021 Gaetan Delannay
 
 # This file is part of Appy.
 
@@ -20,11 +20,11 @@ from appy.px import Px
 from appy import ui, utils
 
 # Error messages - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-TABS_COLUMNS_ERROR = 'A tabs-style group must have a single column.'
-GRID_COLUMNS_ERROR = 'For a grid-style group, you must specify an even number '\
-  'of columns, in order to produce couples of label/field columns. For every ' \
-  'couple, the first columns holds a field label and the second one holds ' \
-  'the field content.'
+TB_COLS_ERR = 'A tabs-style group must have a single column.'
+G_COLS_ERR  = 'For a grid-style group, you must specify an even number of ' \
+              'columns, in order to produce couples of label/field columns. ' \
+              'For every couple, the first columns holds a field label and ' \
+              'the second one holds the field content.'
 
 #- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 class Group:
@@ -133,11 +133,11 @@ class Group:
         # Standardize or check columns depending on group style
         if style == 'tabs':
             # There must be a unique column
-            if len(self.columns) > 1: raise Exception(TABS_COLUMNS_ERROR)
+            if len(self.columns) > 1: raise Exception(TB_COLS_ERR)
         elif style == 'grid':   
             # grid has always an even number of columns (couples of label/field
             # columns)
-            if len(self.columns)%2: raise Exception(GRID_COLUMNS_ERROR)
+            if len(self.columns) % 2: raise Exception(G_COLS_ERR)
 
     def _setLabelCss(self, labelCss, style):
         '''For "sectionX"-style groups, the applied CSS class is by default the
@@ -220,8 +220,9 @@ class UiGroup:
     # Render the group title, description and help
     pxHeader = Px('''
      <!-- Title -->
-     <tr><td colspan=":len(field.columnsWidths)" class=":field.labelCss"
-             align=":dleft">
+     <tr if="field.hasLabel">
+      <td colspan=":len(field.columnsWidths)" class=":field.labelCss"
+          align=":dleft">
        <x>::_(field.labelId)</x><x if="field.hasHelp">:field.pxHelp</x>
       </td>
      </tr>
@@ -452,5 +453,5 @@ class UiGroup:
         if self.style == 'fieldset': return
         parent = self.group.group
         if parent and (parent.style in ('tabs', 'grid')): return
-        return self.hasLabel
+        return self.hasLabel or self.hasDescr
 #- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
