@@ -96,7 +96,8 @@ class Hour(Field):
 
     def getRequestSuffix(self): return '_hour'
 
-    def getStorableValue(self, o, value, complete=False):
+    def getStorableValue(self, o, value, single=False):
+        '''Convert the string p_value to a tuple'''
         if not self.isEmptyValue(o, value):
             return tuple(map(int, value.split(':')))
 
