@@ -436,7 +436,7 @@ class List(Field):
                 setattr(r, name, subValue)
         return r
 
-    def getStorableValue(self, o, value, complete=False):
+    def getStorableValue(self, o, value, single=False):
         '''Gets p_value in a form that can be stored in the database'''
         return [self.getStorableRowValue(o, v) for v in value]
 
