@@ -32,9 +32,9 @@ class Multilingual:
     '''Mixin class injected into any Field whose content can be multilingual'''
 
     # Default values to render when field values are empty
-    emptyDefault = {'view': '-', 'edit': ''}
+    emptyDefault = {'view': '-', 'edit': '', 'cell': ''}
     # Default top space (in pixels) to apply in pxLanguage
-    lgTop = {'view': 1, 'edit': 3}
+    lgTop = {'view': 1, 'edit': 3, 'cell': 3}
 
     # Note that multilinguality is a dynamic feature: field values can be
     # unilingual or multilingual, depending on some condition on the container
@@ -137,7 +137,7 @@ class Multilingual:
             value = values[self.name]
             del(values[self.name])
             for lg in languages:
-                lgPrev = value.get(lg)
+                lgPrev = value.get(lg) if value else None
                 lgCurr = o.values.get(self.name).get(lg)
                 if lgPrev != lgCurr:
                     values[(self.name, lg)] = lgPrev
@@ -254,7 +254,7 @@ class Multilingual:
         index = self.getIndexType(True)
         return index.toString(o, r) if searchable else index.toIndexed(r, self)
 
-    def getStorableValue(self, o, value, complete=False):
+    def getStorableValue(self, o, value, single=False):
         # If no object is passed, assume the field is unilingual
         if o is None:
             return self.getUniStorableValue(o, value)
