@@ -97,7 +97,8 @@ class Password(Field):
         '''Is p_password valid ?'''
         # Password must have a minimum length
         if len(password) < self.minLength:
-            return o.translate('password_too_short', mapping={'nb': 8})
+            return o.translate('password_too_short',
+                               mapping={'nb': self.minLength})
         # Ensure the "confirm" value is filled and is the same as p_password
         if o.req['%s_confirm' % self.name] != password:
             return o.translate('passwords_mismatch')
