@@ -61,7 +61,8 @@ class Config:
         # allowing to contact LibreOffice in server mode. If it is not the case,
         # specify here the absolute path to a UNO-compliant Python interpreter.
         self.unoEnabledPython = None
-        # The port for contacting LibreOffice
+        # The port for contacting LibreOffice (LO). You can specify a list or
+        # tuple of ports, if several LO instances are running.
         self.libreOfficePort = 2002
 
 #- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -696,7 +697,7 @@ class Pod(Field):
         return r
 
     def getDownloadName(self, o, template, format=None, queryRelated=False,
-                        bypassMethod=False):
+                        bypassMethod=False, titleMethod=None):
         '''Gets the name of the pod result as will be seen by the user that will
            download it. Ensure the returned name is not too long for the OS that
            will store the downloaded file with this name.'''
@@ -704,13 +705,19 @@ class Pod(Field):
         # for p_template.
         if not bypassMethod and self.downloadName:
             name = self.downloadName(o, template)
-            if name: return '%s.%s' % (name, format) if format else name
+            if name:
+                return '%s.%s' % (name, format) if format else name
         # Compute the default download name
         fileName = Normalize.fileName(self.getTemplateName(o, template))[:40]
         if not queryRelated:
             # This is a POD for a single object: personalize the file name with
-            # the object title.
-            title = o.getShownValue('title')
+            # the object title. If the name of a method is passed in
+            # p_titleMethod, it will be used on p_obj instead of getting its
+            # title via standard method m_getShownValue.
+            if titleMethod:
+                title = getattr(o, titleMethod)()
+            else:
+                title = o.getShownValue('title')
             fileName = '%s-%s' % (Normalize.fileName(title)[:40], fileName)
         return '%s.%s' % (fileName, format) if format else fileName
 
