@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
 #- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-# Copyright (C) 2007-2020 Gaetan Delannay
+# Copyright (C) 2007-2021 Gaetan Delannay
 
 # This file is part of Appy.
 
@@ -22,17 +22,22 @@ UPLOADED = 'file "%s" uploaded in Ref "%d.%s" via rich "%s".'
 
 #- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 import sys
+from xml.sax._exceptions import SAXParseException
 
 from appy.px import Px
 from appy.ui.layout import Layouts
 from appy.model.fields import Field
 from appy.xml.cleaner import Cleaner
 from appy.utils.diff import HtmlDiff
+from appy.utils.inject import Injector
 from appy.model.fields.text import Text
 from appy.utils import string as sutils
 from appy.ui.layout import Layouts, Layout
 from appy.model.fields.multilingual import Multilingual
 
+#- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+XML_ERROR   = 'Error while reading content of field %s on %s. %s.'
+
 #- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 class Rich(Multilingual, Field):
     '''Field allowing to encode a "rich" text, based on XHTML and external
@@ -99,11 +104,14 @@ class Rich(Multilingual, Field):
     # Unilingual view and cell
     viewUni = cellUni = Px('''
      <x var="inlineEdit=field.getAttribute(o, 'inlineEdit');
+             css=field.getAttribute(o, 'viewCss');
              mayAjaxEdit=inlineEdit and (layout != 'cell') and not \
-                       showChanges and guard.mayEdit(o, field.writePermission)">
-      <div if="not mayAjaxEdit" class="xhtml">::value or '-'</div>
+                       showChanges and guard.mayEdit(o, field.writePermission);
+             value=field.injectContent(o, value) if field.inject else value">
+      <div if="not mayAjaxEdit"
+           class=":css">::value or field.valueIfEmpty</div>
       <x if="mayAjaxEdit" var2="name=lg and ('%s_%s' % (name, lg)) or name">
-       <div class="xhtml" contenteditable="true"
+       <div class=":css" contenteditable="true"
             id=":'%d_%s_ck' % (o.iid, name)">::value or '-'</div>
        <script if="mayAjaxEdit">::field.getJsInlineInit(o, name, lg)</script>
       </x>
@@ -132,7 +140,8 @@ class Rich(Multilingual, Field):
       sheight=None, persist=True, styles=defaultStyles, customStyles=None,
       documents=False, spellcheck=False, languages=('en',),
       languagesLayouts=None, inlineEdit=False, toolbar='Standard', view=None,
-      cell=None, edit=None, xml=None, translations=None):
+      cell=None, edit=None, xml=None, translations=None, inject=False,
+      valueIfEmpty='', viewCss='xhtml'):
         # The list of styles that the user will be able to select in the styles
         # dropdown (within CKEditor) is defined hereafter.
         self.styles = styles
@@ -169,8 +178,74 @@ class Rich(Multilingual, Field):
         self.documents = documents
         # Do we run the CK spellchecker ?
         self.spellcheck = spellcheck
-        # What toolbar is used ? Possible values are "Standard" or "Simple"
+        # What toolbar is used ? Possible values are "Standard" or "Simple".
         self.toolbar = toolbar
+        # If p_inject is True, the XHTML chunk contained in a rich field is
+        # allowed to contain "a" tags of the form:
+        #
+        #      (a)      <a href="<url>">py: <part_specifier></a>
+        #      (b)     <a href="<anything>">px: <object>*<px></a>
+        #
+        # These links will not be rendered as-is: they will represent as many
+        # placeholders for injecting other content.
+        #
+        #                            ------------
+        #                            | Case (a) |
+        #                            ------------
+        #
+        # Each URL must point to a pure textual resource containing Python code.
+        # When rendering this link, Appy will download the code file and extract
+        # from it the part corresponding to <part_specifier>. Possible code
+        # specifiers are the following.
+        # ----------------------------------------------------------------------
+        #  c_<name>    | This will extract the definition of *c*lass named
+        #              | <name>, including its subsequent docstring and comment
+        #              | lines, until the first line of not-commented code is
+        #              | reached, or a comment starting with "# ~" is
+        #              | encountered.
+        # ----------------------------------------------------------------------
+        #  s_<cn>.<mn> | This will extract the *s*ignature of method named <mn>
+        #              | in class named <cn>, its subsequent docstring and
+        #              | comment lines, until the first not-commented line of
+        #              | code is reached, or a comment starting with "# ~" is
+        #              | encountered.
+        # ----------------------------------------------------------------------
+        #  m_<cn>.<mn> | This will extract the complete method named <mn> (as
+        #              | defined in class named <cn>), including its body.
+        # ----------------------------------------------------------------------
+        #
+        #                            ------------
+        #                            | Case (b) |
+        #                            ------------
+        # 
+        # This case is used to inject the content of a PX. The content of the
+        # "a" tag must start with "px:", followed by a specifier made of 2
+        # parts, separated by an asterisk (*):
+        # ----------------------------------------------------------------------
+        # "object"  | must be the name of an object, class or module being
+        #           | available in the current PX context ;
+        # ----------------------------------------------------------------------
+        #   "px"    | is the name of the PX to use. It must correspond to an
+        #           | attribute, available on "object", and be an instance of
+        #           | class appy.px.Px.
+        # ----------------------------------------------------------------------
+        #
+        # Note that, when using POD to dump content of Rich fields via the xhtml
+        # function, special "a" tags as described hereabove (cases (a) and (b))
+        # will not be included by default in the result. In order to enable
+        # that, use parameter inject=True, ie:
+        #
+        #     do ...
+        #     from xhtml(o.someRichField, inject=True)
+        #
+        self.inject = inject
+        # The value to show on non-edit layouts if the field is empty
+        self.valueIfEmpty = valueIfEmpty
+        # When rendering rich content on view or cell layout, standard Appy CSS
+        # class named "xhtml" is applied. If you want to specify another class,
+        # use the following attribute. A method can also be passed.
+        self.viewCss = viewCss
+        # ~~~
         # Call the base constructors
         Multilingual.__init__(self, languages, languagesLayouts)
         Field.__init__(self, validator, multiplicity, default, defaultOnEdit,
@@ -190,8 +265,8 @@ class Rich(Multilingual, Field):
            between successive versions, from the very first stored version in
            p_o's history to the currently stored p_value.
 
-           If p_i is given, p_value is p_self's value as stored in the entry
-           whose index is p_i-1 in p_o's history, and the method will return a
+           If p_i is not None, p_value is p_self's value as stored in the entry
+           whose index is p_i+1 in p_o's history, and the method will return a
            diff between it and p_value's subsequent version, either to be found
            in a more recent entry in p_o's history or, failing that, the
            currently stored value on p_o.'''
@@ -237,6 +312,13 @@ class Rich(Multilingual, Field):
             r = self.getDiffValue(o, r, language=contentLanguage)
         return r
 
+    def validateUniValue(self, o, value):
+        '''Ensure p_value as will be stored (=cleaned) is valid XHTML'''
+        try:
+            Cleaner().clean(value)
+        except SAXParseException as err:
+            return o.translate('bad_xml', mapping={'error': str(err)})
+
     def getSearchValue(self, req, value=None):
         '''The input widget for a Rich field is of type "text". So behave like a
            Text field in that case.'''
@@ -244,12 +326,11 @@ class Rich(Multilingual, Field):
 
     def getHistoryValue(self, o, value, i, language=None, empty='-'):
         '''For a Rich field, instead of showing the previous p_value in p_o's
-           history, we show a XHTML diff between p_value and the new value, as
-           currently stored on p_o or as stored in a more recent entry in p_o's
-           history.'''
+           history, show a XHTML diff between p_value and a newer version of it
+           in p_o's history before p_i, or, if not found, the value as currently
+           stored on p_o.'''
         r = Field.getHistoryValue(self, o, value, i, language, empty=None)
-        return empty if not r else self.getDiffValue(o, value, i=i-1,
-                                                     language=language)
+        return empty if not r else self.getDiffValue(o, value, i-1, language)
 
     def getUniStorableValue(self, o, value):
         '''Gets the p_value as can be stored in the database within p_obj'''
@@ -259,15 +340,21 @@ class Rich(Multilingual, Field):
         # case we can't remove style-related information.
         try:
             value = Cleaner().clean(value)
-        except Cleaner.Error:
+        except SAXParseException as err:
             # Errors while parsing p_value can't prevent the user from storing
             # it.
-            pass
+            o.log(XML_ERROR % (self.name, o.id, str(err)), type='warning')
         # Manage maxChars
         max = self.maxChars
         if max and (len(value) > max): value = value[:max]
         return value
 
+    def injectContent(self, o, value):
+        '''When p_self.inject is True, this method replaces every "injection
+           link" found in p_value with the appropriate content.'''
+        if not self.inject: return value
+        return Injector.run(value, o)
+
     def getTextareaStyle(self):
         '''On "edit", get the content of textarea's "style" attribute'''
         # If the width is expressed as a string, the field width must be
@@ -337,7 +424,8 @@ class Rich(Multilingual, Field):
 
     def getJs(self, layout, r, config):
         '''A rich field depend on CKeditor'''
-        if layout not in ('edit', 'view'): return
+        if (layout not in ('edit', 'view')) or \
+           ((layout == 'view') and not self.inlineEdit): return
         # Compute the URL to ckeditor CDN
         ckUrl = Rich.cdnUrl % (config.ui.ckVersion, config.ui.ckDistribution)
         if ckUrl not in r: r.append(ckUrl)
