@@ -127,9 +127,11 @@ class Select(Field):
     class Layouts(Layouts):
         '''Select-specific layouts'''
         d  = Layouts(Layout('d2-l-f;rv=', width=None))
+        # With a description, but no label
+        dn = Layouts(Layout('d-frv=', width=None))
         g  = Layouts(edit=Layout('f;rv=', width=None),
                      view=Layout('fl', width=None))
-        gd = Layouts(edit=Layout('d2-f;rv=', width=None),
+        gd = Layouts(edit=Layout('drv-f=', width=None),
                      view=Layout('fl', width=None))
 
         @classmethod
@@ -161,6 +163,8 @@ class Select(Field):
              possibleValues=field.getPossibleValues(o, withTranslations=True, \
                withBlankValue=isSelect);
              charsWidth=field.getWidthInChars(False)">
+
+     <!-- As a "select" widget -->
      <select if="isSelect" name=":name" id=":name" class=":masterCss"
        multiple=":isMultiple" onchange=":field.getOnChange(o, layout)"
        size=":field.getSelectSize(False, isMultiple)"
@@ -169,7 +173,18 @@ class Select(Field):
               selected=":field.isSelected(o, name, val, rawValue)"
               title=":text">:Px.truncateValue(text, charsWidth)</option>
      </select>
+
+     <!-- As radio buttons or checkboxes -->
      <x if="not isSelect">
+
+      <!-- (Un)check all -->
+      <div if="field.render == 'checkbox' and len(possibleValues) &gt; 1"
+           class="divAll" var="allId='%s_all' % name">
+       <input type="checkbox" class="checkAll" id=":allId" name=":allId"
+              onclick="toggleCheckboxes(this)"/>
+       <label lfor=":allId">:_('check_uncheck')</label>
+      </div>
+
       <div for="val, text in possibleValues"
            var2="vid='%s_%s' % (name, val)">
        <input type=":field.render" name=":name" id=":vid" value=":val"
@@ -386,7 +401,7 @@ class Select(Field):
                 # ... from the request if available
                 requestValue = master.getRequestValue(o)
                 masterValues = master.getStorableValue(o, requestValue,
-                                                       complete=True)
+                                                       single=True)
             elif not className:
                 # ... or from the database if we are editing an object
                 masterValues = master.getValue(o)
@@ -455,9 +470,9 @@ class Select(Field):
                     break
         if error: return o.translate('bad_select_value')
 
-    def getStorableValue(self, o, value, complete=False):
+    def getStorableValue(self, o, value, single=False):
         '''Get a multivalued value when appropriate'''
-        if value and self.isMultiValued() and \
+        if value and not single and self.isMultiValued() and \
            (type(value) not in utils.sequenceTypes):
             value = [value]
         return value
