@@ -153,9 +153,7 @@ class String(Multilingual, Field):
            valid, the method returns True.'''
         if not value: return True
         # First, remove any non-digit or non-letter char
-        v = ''
-        for c in value:
-            if alpha.match(c): v += c
+        v = Normalize.alphanum(value)
         # Maximum size is 34 chars
         if (len(v) < 8) or (len(v) > 34): return False
         # 2 first chars must be a valid country code
@@ -163,11 +161,11 @@ class String(Multilingual, Field):
         # 2 next chars are a control code whose value must be between 0 and 96.
         try:
             code = int(v[2:4])
-            if (code < 0) or (code > 96): return False
+            if (code < 0) or (code > 97): return False
         except ValueError:
             return False
         # Perform the checksum
-        vv = v[4:] + v[:4] # Put the 4 first chars at the end.
+        vv = v[4:] + v[:4] # Put the 4 first chars at the end
         nv = ''
         for c in vv:
             # Convert each letter into a number (A=10, B=11, etc)
@@ -205,7 +203,7 @@ class String(Multilingual, Field):
       sdefault='', scolspan=1, swidth=None, sheight=None, persist=True,
       transform='none', placeholder=None, languages=('en',),
       languagesLayouts=None, inlineEdit=False, view=None, cell=None, edit=None,
-      xml=None, translations=None, readonly=False):
+      xml=None, translations=None, readonly=False, stripped=True):
         # Does this field store an URL ?
         self.isUrl = validator == String.URL
         # "placeholder", similar to the HTML attribute of the same name, allows
@@ -224,6 +222,9 @@ class String(Multilingual, Field):
         # the rendered input field, on edit layouts, will have attribute
         # "readonly" set.
         self.readonly = readonly
+        # Must the field content be stripped as soon as it is encoded by the
+        # user ?
+        self.stripped = stripped
         # Call the base constructors
         Multilingual.__init__(self, languages, languagesLayouts)
         Field.__init__(self, validator, multiplicity, default, defaultOnEdit,
@@ -304,6 +305,9 @@ class String(Multilingual, Field):
 
     def getUniStorableValue(self, o, value):
         '''Manage a potential string transform and max chars'''
+        # Strip this p_value if required
+        if value and self.stripped:
+            value = value.strip()
         # Apply transform if required
         if value:
             value = self.applyTransform(value)
