@@ -81,7 +81,7 @@ class Switch(Field):
             if master and master.valueIsInRequest(o, req):
                 # ... via the master value if present in the request
                 reqValue = master.getRequestValue(o)
-                masterValue = master.getStorableValue(o,reqValue,complete=True)
+                masterValue = master.getStorableValue(o, reqValue, single=True)
                 fieldset = self.masterValue(o, masterValue)
             else:
                 # ... via the stored value
