@@ -610,12 +610,14 @@ class Text(Multilingual, Field):
                 align='left' if inToolbar else 'right';
                 fdir='row' if inToolbar else 'column'"
            style=":'float:%s;display:flex;flex-direction:%s' % (align, fdir)">
-       <div><img id=":'%s_save' % tid" src=":url('save')"
-                 class=":'clickable icon' if inToolbar else 'inlineIcon'"
-                 title=":_('object_save')"/></div>
-       <div><img id=":'%s_cancel' % tid" src=":url('cancel')"
-                 class=":'clickable icon' if inToolbar else 'inlineIcon'"
-                 title=":_('object_cancel')"/></div>
+       <div>
+        <img id=":'%s_save' % tid" src=":url('save.svg')"
+             class=":'iconS %s' % ('clickable' if inToolbar else 'inlineIcon')"
+             title=":_('object_save')"/></div>
+       <div>
+        <img id=":'%s_cancel' % tid" src=":url('cancel.svg')"
+             class=":'iconS %s' % ('clickable' if inToolbar else 'inlineIcon')"
+             title=":_('object_cancel')"/></div>
       </div>
       <script>:'prepareForAjaxSave(%s,%s,%s,%s)' % \
                (q(name), q(o.iid), q(o.url), q(hostLayout))</script>''')
