@@ -432,6 +432,15 @@ class Class(Meta):
         r = getattr(self.python, 'createExclude', ())
         return r(o) if callable(r) else r
 
+    def getSaveText(self, o):
+        '''Returns the translated text for button "save" when creating or
+           editing this p_o(bject).'''
+        if o.isTemp():
+            label = getattr(self.python, 'createLabel', 'object_save')
+        else:
+            label = 'object_save'
+        return o.translate(label)
+
     def getConfirmPopupWidth(self, popup):
         '''Gets the width (in pixels, as an integer value), of the confirmation
            popup possibly shown when creating or editing p_self's instances.'''
@@ -588,22 +597,47 @@ class Class(Meta):
         r = getattr(self.python, 'listCss', None)
         return r if r else 'list'
 
+    def mayEditEventComment(self, o, event, user, isManager):
+        '''May p_user edit the comment on this p_event, coming from p_o's
+           history ?'''
+        r = getattr(self.python, 'editHistoryComments', None)
+        # Call the potentially defined custom method
+        if callable(r): r = r(o, event)
+        # The comment may be edited, but not for any event, by any user
+        if r:
+            # Allow edition if logged user is a Manager (p_isManager is True) or
+            # if he is the p_event's author.
+            return isManager or user.login == event.login
+
     def getTitleMode(self):
         '''Gets the "title mode" for instances of this class'''
         # Consult homonym method on class appy.model.searches.UiSearch
         return getattr(self.python, 'titleMode', None)
 
-    def hasSubTitle(self):
-        '''Does p_self define a method "getSubTitle"?'''
-        # This method allows to fill a zone under the title of p_self's
-        # instances when rendered in a table.
+    def toggleSubTitles(self, tool, from_):
+        '''Must the mechanism for toggling sub-titles be enabled on p_self ?'''
+        # Sub-titles may appear, within lists or grids of p_self's instances,
+        # under the title of every instance.
+        # ~~~
+        # p_from may hold a Ref field. In that case, toggling sub-titles occurs
+        # in the context of a list of objects being tied via this field.
+        # ~~~
+        # Check first if the mechanism is explicitly disabled
+        if from_ and from_.toggleSubTitles is not None:
+            toggle = from_.toggleSubTitles
+        else:
+            toggle = getattr(self.python, 'toggleSubTitles', None)
+        if callable(toggle): toggle = toggle(tool)
+        if toggle is False: return
+        # Enable it if the class defines a method named "getSubTitle"
         return hasattr(self.python, 'getSubTitle')
 
     def getPortletBottom(self, tool):
         '''Is there a custom zone to display at the bottom of the portlet zone
            for this class ?'''
-        if not hasattr(self.python, 'getPortletBottom'): return
-        return self.python.getPortletBottom(tool)
+        r = getattr(self.concrete, 'portletBottom', None)
+        if r is None: return
+        return r if isinstance(r, Px) else r(tool)
 
     def getListColumns(self, tool):
         '''Return the list of columns to display when rendering p_self's
