@@ -88,7 +88,7 @@ class Page(Base):
                 o = getattr(self, name)
                 label = self.translate(self.getField(name).labelId)
                 r.append('<div class="discreet">%s: <a href="%s">%s</a></div>' \
-                         % (esc(label), o.url, esc(o.title)))
+                         % (esc(label), o.url, esc(o.getShownValue())))
         return '\n'.join(r)
 
     # A warning: image upload is impossible while the page is temp
@@ -255,7 +255,8 @@ class Page(Base):
     pages = Ref(None, multiplicity=(0,None), add=True, link=False,
       composite=True, back=Ref(attribute='parent', show=False, **pa),
       showHeaders=True, actionsDisplay='inline', show=showSubPages,
-      numbered=True, checkboxes=lambda o: o.allows('write'), **pa)
+      numbered=True, checkboxes=lambda o: o.allows('write'),
+      toggleSubTitles=False, **pa)
 
     def getParents(self, includeMyself=True):
         '''Returns, as a set, p_self's parents, including p_self itself if
@@ -321,9 +322,9 @@ class Page(Base):
         # A specific CSS class wil be applied for a selected page
         css = ' class="current"' if isSelected else ''
         # If p_self has parents, we must render it with a margin-right
-        style = ' style="margin-left:%dpx"' % (level * 5) if level else ''
+        style = ' style="margin-left:%dpx"' % (level * 8) if level else ''
         r = ['<div%s><a href="%s"%s>%s</a></div>' % \
-             (style, self.url, css, Escape.xhtml(self.title))]
+             (style, self.url, css, Escape.xhtml(self.getShownValue()))]
         if isSelected and not self.isEmpty('pages'):
             for sub in self.pages:
                 r.append(sub.inPortlet(selected, level+1))
@@ -355,7 +356,7 @@ class Page(Base):
        <option value="">:_('goto_link')</option>
        <option for="page in pages"
                value=":'%s/public?rp=%s' % (tool.url, page.iid)"
-               selected=":req.rp == str(page.iid)">:page.title</option>
+               selected=":req.rp==str(page.iid)">:page.getShownValue()</option>
       </select>''',
 
      js='''
