@@ -256,7 +256,8 @@ class Search:
                  showNav='both', navAlign='right', translated=None,
                  translatedDescr=None, checkboxes=False, checkboxesDefault=True,
                  container=None, add=False, resultModes=None, shownInfo=None,
-                 actions=None, rowAlign='top', pageLayoutOnView=None, **fields):
+                 actions=None, rowAlign='top', pageLayoutOnView=None,
+                 thumbnailCss='thumbnail', **fields):
         # "name" is mandatory, excepted in some special cases (ie, when used as
         # "select" param for a Ref field).
         self.name = name
@@ -318,6 +319,9 @@ class Search:
         # You may override the page layout used when accessing, on the "view"
         # layout, every search result, by using the following attribute.
         self.pageLayoutOnView = pageLayoutOnView
+        # The name of the CSS class to use for rendering thumbnails, when result
+        # mode is "grid".
+        self.thumbnailCss = thumbnailCss
 
     def init(self, class_):
         '''Lazy search initialisation'''
@@ -520,6 +524,15 @@ class Search:
         # Return a UiSearch if required
         return r if not ui else UiSearch(r, tool, ctx, initiator, name)
 
+    @classmethod
+    def initContext(class_, searchName, tool, context):
+        '''Initialises the current PX p_context with variables related to this
+           p_search.'''
+        ui = class_.get(searchName, tool, context.class_, context)
+        context.uiSearch = ui
+        context.resultModes = ui.getModes()
+        context.mode = ui.getMode()
+
     @classmethod
     def getRefInfo(class_, tool, info=None, nameOnly=True, sep=':'):
         '''When a search is triggered in the context of a Ref field, this method
@@ -638,24 +651,41 @@ class Search:
      <div var="hook=uiSearch.getRootHook()" id=":hook">
       <script>:uiSearch.getCbJsInit(hook)</script>
       <x if="not mode.inField">::ui.Globals.getForms(tool)</x>
-      <div align=":dright" if="len(resultModes) &gt; 1">
-       <select name="px"
-               onchange=":'switchResultMode(this, %s)' % q('searchResults')">
-        <option for="mode in resultModes"
-                value=":mode">:uiSearch.Mode.getText(mode, _)</option>
-       </select>
+
+      <!-- Switch mode -->
+      <div if="len(resultModes) &gt; 1" class="modes">
+       <img for="cls in mode.getClasses(resultModes)"
+            name=":cls.name" title=":cls.getText(_)"
+            src=":url(cls.icon)" class="clickable iconL"
+            style=":'display:%s' % ('block' if mode.name!=cls.name else 'none')"
+            onclick="switchResultMode(this)"/>
       </div>
+
+      <!-- Search results -->
       <x>:uiSearch.pxResult</x>
      </div>''',
 
+     css='''.modes{ display:flex; flex-wrap:wrap; grid-gap:15px;
+                    margin:5px 0 } ''',
+
      js='''
-       function switchResultMode(select, hook) {
-         var mode = select.options[select.selectedIndex].value;
-         askAjax(hook, null, {'resultMode': mode});
+       function switchResultMode(img, hook) {
+         // Hide the mode corresponding to p_img
+         img.style.display = 'none';
+         // Display any other mode
+         var images=img.parentNode.children;
+         for (var i=0; i<images.length; i++) {
+           if (images[i] != img) images[i].style.display = 'block';
+         }
+         askAjax('searchResults', null, {'resultMode': img.name});
        }''',
 
      template=Template.px, hook='content')
 
+    # Same as PX "results" hereabove, but without template, to be used as inner
+    # PX from another one (ie, within a field).
+    innerResults = results.clone(keepTemplate=False)
+
     traverse['jresults'] = True
     @classmethod
     def jresults(class_, tool):
