@@ -23,7 +23,7 @@ class Gridder:
 
     def __init__(self, width='350px', gap='20px', justifyContent='space-evenly',
                  alignContent='space-evenly', cols=None, margin=None,
-                 showFields=True):
+                 showFields=True, flex=False):
         # ~~~
         # If a p_width is specified, there will not be a fixed number of
         # columns: this number will depend on available space and this width.
@@ -60,21 +60,30 @@ class Gridder:
         #- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
         # If p_showFields is False, element (d) will not be rendered.
         self.showFields = showFields
+        # If p_flex is True, a flex layout will be used instead of a grid layout
+        self.flex = flex
 
     def getContainerStyle(self):
         '''Returns the CSS styles that must be applied to the grid container
            element.'''
-        # Determine columns
-        if self.cols:
-            columns = 'repeat(%d, 1fr)' % self.cols
+        if self.flex:
+            display = 'flex'
+            specific = '; flex-wrap:wrap'
         else:
-            columns = 'repeat(auto-fill, minmax(%s, 1fr))' % self.width
-        # Determine margins
-        margin = '; margin:%s' % self.margin if self.margin else None
-        
+            display = 'grid'
+            # Determine grid-specific parameters
+            if self.cols:
+                columns = 'repeat(%d,1fr)' % self.cols
+            else:
+                columns = 'repeat(auto-fill,minmax(%s,1fr))' % self.width
+            specific = '; grid-template-columns:%s' % columns
+        # Determine common parameters
+        margin  = '; margin:%s' % self.margin if self.margin else ''
+        justify = '; justify-content:%s;' % self.justifyContent \
+                  if self.justifyContent else ''
+        align   = '; align-content:%s;' % self.alignContent \
+                  if self.alignContent else ''
         # Return the CSS code
-        return 'display:grid; grid-template-columns:%s; ' \
-               'grid-gap:%s; justify-content:%s; align-content:%s%s' % \
-               (columns, self.gap, self.justifyContent, self.alignContent,
-                margin)
+        return 'display:%s; grid-gap:%s;%s%s%s%s' % \
+               (display, self.gap, justify, align, specific, margin)
 #- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
