@@ -1,7 +1,7 @@
 '''Initiators for searches whose results are shown in popups'''
 
 #- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-# Copyright (C) 2007-2020 Gaetan Delannay
+# Copyright (C) 2007-2021 Gaetan Delannay
 
 # This file is part of Appy.
 
@@ -136,7 +136,7 @@ class SearchInitiator:
         self.backFromPopupUrl = None
 
     # Conform to the Initiator API
-    def checkAllowed(self): pass
+    def checkAllowed(self, log=False): pass
     def updateParameters(self, params): pass
     def manage(self, new): pass
     def goBack(self): return 'view'
