@@ -66,12 +66,25 @@ class Mode:
         return r
 
     @classmethod
-    def getText(class_, name, _):
+    def getClasses(class_, names):
+        '''Return the Mode sub-classes corresponding to their p_names'''
+        # Todo: manage custom modes
+        return [eval(name.capitalize()) for name in names]
+
+    @classmethod
+    def getText(class_, _):
         '''Gets the i18n text corresponding to mode named p_name'''
+        name = class_.__name__.lower()
         name = name.rsplit('_', 1)[0] if '_' in name else name
         return _('result_mode_%s' % name) if name in Mode.concrete \
                                           else _('custom_%s' % name)
 
+    @classmethod
+    def isGrid(class_, o):
+        '''Are we currently rendering a Search with "grid" mode ?'''
+        ctx = o.traversal.context
+        return ctx and ctx.mode and isinstance(ctx.mode, Grid)
+
     def __init__(self, uiSearch):
         # The tied UI search
         self.uiSearch = uiSearch
@@ -97,6 +110,7 @@ class Mode:
         self.newSearchUrl = None
         # Is the search triggered from a Ref field ?
         self.fromRef = False
+        self.refField = None
         # Is the search integrated into another field ?
         self.inField = False
         # The target for "a" tags
@@ -125,7 +139,9 @@ class Mode:
             self.newSearchUrl = '%s/Search/advanced?className=%s%s' % \
                                 (tool.url, search.container.name, part)
         self.fromRef = bool(ifield)
-        self.inField = ifield and ('search*' in req.search)
+        # This search may lie within another field (a Ref or a Computed)
+        self.inField = (ifield and ('search*' in req.search)) or \
+                       (req.search and ',' in req.search)
 
     def getAjaxData(self):
         '''Initializes an AjaxData object on the DOM node corresponding to the
@@ -149,8 +165,12 @@ class Mode:
         self.updateAjaxParameters(params)
         # Convert params into a JS dict
         params = sutils.getStringFrom(params)
-        return "new AjaxData('%s/Search/batchResults', 'POST', %s, '%s')" % \
-               (self.tool.url, params, self.hook)
+        # Set the appropriate context object for the PX. If the search is within
+        # a field, this context object is the object containing the field. Else,
+        # it is the tool.
+        id = name.split(',',1)[0] if ',' in name else 'tool'
+        return "new AjaxData('%s/%s/Search/batchResults', 'POST', %s, '%s')" % \
+               (self.tool.siteUrl, id, params, self.hook)
 
     def updateAjaxParameters(self, params):
         '''To be overridden by subclasses for adding Ajax parameters
@@ -171,13 +191,19 @@ class Mode:
 class List(Mode):
     '''Displays search results as a table containing one row per object'''
 
+    # Icon for switching to this mode
+    icon = 'list.svg'
+
+    # Name for this mode
+    name = 'list'
+
     px = Px('''
      <table class=":class_.getResultCss(layout)" width="100%">
       <!-- Headers, with filters and sort arrows -->
       <tr if="showHeaders">
        <th for="column in mode.columns"
            var2="field=column.field" width=":column.width" align=":column.align"
-           class=":(field == '_checkboxes') and mode.cbClass or ''">
+           class=":mode.cbClass if field == '_checkboxes' else ''">
         <x if="column.header">
          <img if="field == '_checkboxes'" src=":url('checkAll.svg')"
               class="clickable iconM" title=":_('check_uncheck')"
@@ -199,7 +225,8 @@ class List(Mode):
           <!-- Filter widget -->
           <x var="field,filterPx=field.getFilterPx()"
              if="filterPx and mode.showFilters">:filterPx</x>
-          <x if="ui.Title.showSub(class_, field)">:ui.Title.pxSub</x>
+          <x if="ui.Title.showToggleSub(class_, field, tool, \
+                   from_=mode.refField)">:ui.Title.pxToggleSub</x>
          </x>
         </x>
        </th>
@@ -253,8 +280,8 @@ class List(Mode):
         self.batch.hook = self.hook
         self.objects = self.batch.objects
         # Show sub-titles ? Show filters ?
-        self.showSubTitles = eval(req.showSubTitles or 'False')
-        self.showFilters = self.filters or (self.batch.total > 1)
+        self.showSubTitles = req.showSubTitles == 'True'
+        self.showFilters = self.filters or self.batch.total > 1
         # Every matched object may be selected via a checkbox
         self.rootHook = ui.getRootHook()
         self.checkboxes = ui.checkboxes
@@ -344,6 +371,12 @@ class List(Mode):
 class Grid(List):
     '''Displays search results as a table containing one cell per object'''
 
+    # Icon for switching to this mode
+    icon = 'grid.svg'
+
+    # Name for this mode
+    name = 'grid'
+
     px = Px('''
      <!-- Filters -->
      <div class="gridFilters" if="uiSearch.search.showFilters">
@@ -357,19 +390,29 @@ class Grid(List):
 
      <!-- The grid itself -->
      <div style=":mode.gridder.getContainerStyle()">
-      <div for="o in mode.objects" class="thumbnail"
-           var2="mayView=guard.mayView(o)">
-       <table class="thumbtable">
+      <div for="o in mode.objects" class=":uiSearch.search.thumbnailCss"
+           var2="mayView=guard.mayView(o);
+                 showFields=mode.gridder.showFields">
+
+       <!-- A complete table will all visible fields -->
+       <table class="thumbtable" if="showFields">
         <tr var="@currentNumber=currentNumber + 1" valign="top"
             for="column in mode.columns"
             var2="field=column.field; backHook='searchResults'">
          <td if="field.name == 'title'" colspan="2">:field.pxResult</td>
-         <x if="(field.name != 'title') and mode.gridder.showFields">
+         <x if="field.name != 'title'">
           <td><label lfor=":field.name">::_('label', field=field)</label></td>
           <td>:field.pxResult</td>
          </x>
         </tr>
        </table>
+
+       <!-- The object title only, when other fields must not be shown -->
+       <x if="not showFields"
+          var2="@currentNumber=currentNumber + 1;
+                field=o.getField('title')">:field.pxResult</x>
+
+       <!-- The "more" section -->
        <div class="thumbmore">
         <img src=":url('more')" class="clickable"
              onclick="followTitleLink(this)"/>
@@ -411,6 +454,12 @@ class Grid(List):
 class Calendar(Mode):
     '''Displays search results in a monthly calendar view'''
 
+    # Icon for switching to this mode
+    icon = 'calendar.svg'
+
+    # Name for this mode
+    name = 'calendar'
+
     px = Px('''<x var="layoutType='view';
                        field=tool.getField('calendar')">:field.view</x>''')
 
@@ -601,6 +650,12 @@ class Calendar(Mode):
 class Custom(Mode):
     '''Displays search results via a custom PX'''
 
+    # Icon for switching to this mode
+    icon = 'custom.svg'
+
+    # Name for this mode
+    name = 'custom'
+
     def init(self):
         '''By default, the Custom mode performs full (unpaginated) searches'''
         r = self.tool.executeQuery(self.className, search=self.uiSearch.search,
