@@ -37,7 +37,6 @@ from appy.utils.mail import sendMail
 from appy.ui.template import Template
 from appy.model.fields.ref import Ref
 from appy.server.backup import Backup
-from appy.model.searches import Search
 from appy.model.fields.rich import Rich
 from appy.model.fields import Initiator
 from appy.model.carousel import Carousel
@@ -64,7 +63,6 @@ class Tool(Base):
     ui = appy.ui
     Date = Date
     OPage = OPage
-    Search = Search
     AuthContext = AuthenticationContext
 
     # While most users have generally the read permission on the tool and
@@ -72,9 +70,8 @@ class Tool(Base):
     # Traversing tool/view is thus by default restricted to those having the
     # write permission on the tool.
     traverse = Base.traverse.copy()
-    traverse.update({'ui':True, 'guard':True, 'Search':True,
-                     'AuthContext': 'Authenticated', 'Database':True,
-                     'Server':True, 'view': 'perm:write'})
+    traverse.update({'ui':True, 'guard':True, 'AuthContext': 'Authenticated',
+                     'Database':True, 'Server':True, 'view': 'perm:write'})
 
     Initiator = Initiator
 
@@ -372,9 +369,9 @@ class Tool(Base):
     #  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -
 
     def sendMail(self, to, subject, body, attachments=None, replyTo=None):
-        '''Sends a mail. See doc for appy.utils.mail.sendMail'''
-        sendMail(self.config.mail, to, subject, body, attachments=attachments,
-                 log=self.log, replyTo=replyTo)
+        '''Sends a mail. See doc for appy.utils.mail.sendMail.'''
+        return sendMail(self.config.mail, to, subject, body,
+                        attachments=attachments, log=self.log, replyTo=replyTo)
 
     def computeHomePage(self):
         '''Compute the page that is shown to the user when he hits the app'''
@@ -415,31 +412,6 @@ class Tool(Base):
             # no default home object.
             if user.hasRole('Manager'): return self
 
-    def getGoogleAnalyticsCode(self, handler, config):
-        '''If the config defines a Google Analytics ID, this method returns the
-           Javascript code to be included in every page, allowing Google
-           Analytics to work.'''
-        # Disable Google Analytics when we are in debug mode
-        if handler.server.mode == 'fg': return
-        # Disable Google Analytics if no ID is found in the config.
-        gaId = config.googleAnalyticsId
-        if not gaId: return
-        # Google Analytics must be enabled: return the chunk of Javascript
-        # code specified by Google.
-        code = "var _gaq = _gaq || [];\n" \
-               "_gaq.push(['_setAccount', '%s']);\n" \
-               "_gaq.push(['_trackPageview']);\n" \
-               "(function() {\n" \
-               "  var ga = document.createElement('script'); " \
-               "ga.type = 'text/javascript'; ga.async = true;\n" \
-               "  ga.src = ('https:' == document.location.protocol ? " \
-               "'https://ssl' : 'http://www') + " \
-               "'.google-analytics.com/ga.js';\n" \
-               "  var s = document.getElementsByTagName('script')[0]; " \
-               "s.parentNode.insertBefore(ga, s);\n" \
-               "})();\n" % gaId
-        return code
-
     def formatDate(self, date, format=None, withHour=True, language=None):
         '''Check doc in called method'''
         if not date: return
@@ -486,7 +458,7 @@ class Tool(Base):
      <div if="isAnon and _px_.name == 'home'" class="homeText">
        <img src=":url('homeLogo')"/>
        <!-- The home text must not be shown here, if shown on a public page -->
-       <x if="not tool.isEmpty('defaultPage') and \
+       <x if="not tool.isEmpty('defaultPage') and 
               not cfg.discreetLogin">::tool.defaultPage.content</x>
      </div>
 
