@@ -1,5 +1,5 @@
 #- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-# Copyright (C) 2007-2020 Gaetan Delannay
+# Copyright (C) 2007-2021 Gaetan Delannay
 
 # This file is part of Appy.
 
@@ -16,6 +16,8 @@
 # Appy. If not, see <http://www.gnu.org/licenses/>.
 
 #- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+import time
+
 from appy.px import Px
 from appy.model.base import Base
 from appy.model.fields import Show
@@ -25,6 +27,7 @@ from appy.database.operators import or_
 from appy.utils import string as sutils
 from appy.model.fields.date import Date
 from appy.utils.string import Normalize
+from appy.model.utils import Object as O
 from appy.model.fields.phase import Page
 from appy.model.fields.group import Group
 from appy.model.fields.string import String
@@ -35,6 +38,13 @@ from appy.model.fields.password import Password
 from appy.model.workflow import standard as workflow
 from appy.model.fields.select import Select, Selection
 
+#- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+SCAN_DB    = 'Scanning all database objects...'
+LOGIN_RN   = 'User "%s" has new login "%s".'
+LOGIN_OP   = "Login change: local roles and/or history updated in %d/%d " \
+             "object(s). Done in %.2f''."
+O_WALKED   = '%d objects walked so far...'
+
 #- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 class User(Base):
     '''Base class representing a user'''
@@ -94,7 +104,7 @@ class User(Base):
            layout.'''
         if self.user.login == 'admin' and (self.source != 'sso'): return 'xml'
 
-    encrypted = Computed(show=showEncrypted,
+    encrypted = Computed(show=showEncrypted, label='User',
                          method=lambda o: o.values['password'])
 
     #  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -
@@ -217,6 +227,37 @@ class User(Base):
         if not groupsOnly: r.append(self.login)
         return r
 
+    def setLogin(self, old, new, reindex=True):
+        '''Modifies p_self's login, from p_old to p_new'''
+        start = time.time()
+        self.login = new
+        # Update the email if it corresponds to the login
+        email = self.email
+        if email == old:
+            self.email = new
+        # Update the title
+        self.updateTitle()
+        # Browse all objects of the database and update potential local roles
+        # that referred to the old login.
+        self.log(SCAN_DB)
+        updated = total = 0
+        for tree in self.H().dbConnection.root.iobjects.values():
+            for o in tree.values():
+                total += 1
+                # Update local roles on this object
+                rchanged = o.localRoles.replace(old, new)
+                hchanged = o.history.replaceLogin(old, new)
+                if rchanged or hchanged:
+                    updated += 1
+                    o.reindex()
+                # Log progression
+                if (total % 10000) == 0:
+                    self.log(O_WALKED % total)
+        self.log(LOGIN_RN % (old, new))
+        self.log(LOGIN_OP % (updated, total, time.time()-start))
+        # Reindex p_self, excepted if p_reindex is False
+        if reindex: self.reindex()
+
     def getAllowedFrom(self, roles, logins):
         '''Gets for this user, the value allowing to perform searches regarding
            index "allowed". p_roles are user roles as computed by m_getRoles and
@@ -297,11 +338,11 @@ class User(Base):
         # Compute it
         r = list(self.roles)
         # Add ungrantable roles
-        r.append(self.isAnon() and 'Anonymous' or 'Authenticated')
+        r.append('Anonymous' if self.isAnon() else 'Authenticated')
         # Add group global roles
         for group in self.groups:
             for role in group.roles:
-                if role not in r: r.append(r)
+                if role not in r: r.append(role)
         return r
 
     def hasRole(self, role, o=None):
@@ -447,12 +488,11 @@ class User(Base):
 
     # Display, in the user strip, links to the User instance of the logged user
     pxUserLink = Px('''
-     <a if="config.ui.userLink" href=":user.url">
+     <a if="cfg.userLink" href=":user.url">
       <img src=":url('user.svg')" class="icon"/>
-      <span class="headerText">:user.getFirstName()</span>
+      <span class="topText">:user.getFirstName()</span>
      </a>
-     <x if="not config.ui.userLink">:user.getFirstName()</x>
-     <x var="ctx=config.security.authContext" if="ctx">:ctx.pxLogged</x>''')
+     <x if="not cfg.userLink">:user.getFirstName()</x>''')
 
     #  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -  -
     #  Class methods
@@ -479,10 +519,10 @@ class User(Base):
         '''To identify a user means: get its login, password and authentication
            context. There are several places to look for this information: the
            Appy authentication cookie, HTTP authentication, or credentials from
-           the login form.
+           the login form.'''
 
-           If no user could be identified, the "anon" user, representing an
-           anonymous user, will nevertheless be identified.'''
+        # If no user could be identified, the "anon" user, representing an
+        # anonymous user, will nevertheless be identified.
         handler = guard.handler
         req = handler.req
         login = password = ctx = place = None
@@ -506,7 +546,8 @@ class User(Base):
         # c. Identify the user from the authentication form
         if not login:
             login = req.login
-            if login: login = handler.config.security.transformLogin(login)
+            if login:
+                login = handler.config.security.transformLogin(login.strip())
             password = req.password or ''
             ctx = req.context
             if login: place = 'form'
@@ -541,6 +582,7 @@ class User(Base):
         # Identify the user
         login, password, ctx, place = User.identify(guard)
         config = guard.config.security
+        authContext = config.authContext
         tool = handler.tool
         if place == 'sso':
             # We have found a user already authenticated by a SSO (Single
@@ -562,15 +604,20 @@ class User(Base):
             # authentication context was not found.
             if (user is None) or user.isAnon() or (user.state=='inactive') or \
                (not user.getField('password').check(user, password)) or \
-               (not ctx and config.authContext and \
-                config.authContext.isMandatory(tool) and (place != 'basic')):
+               (not ctx and authContext and authContext.isMandatory(tool) and \
+                (place != 'basic')):
                 # Disable the authentication cookie
                 guard.Cookie.disable(handler)
                 user = handler.dbConnection.root.objects.get('anon')
             else:
-                # The user is authenticated. Create an authentication cookie
-                # for him.
+                # The user is authenticated. Create an authentication cookie for
+                # him. Set a default context when appropriate.
+                if authContext and not ctx:
+                    ctx = authContext.getDefaultContext(tool, user)
                 guard.Cookie.write(handler, user.login, password, ctx)
+        # Set, on the guard, when present, attributes related to the
+        # authentication context.
+        if ctx and authContext: authContext._setOnGuard(tool, user, guard, ctx)
         return user
 
     @classmethod
