@@ -113,7 +113,7 @@ class Event(persistent.Persistent):
     # The PX displaying details about an event (basically the event's comment)
     pxDetail = Px('''
      <x var="eventId=event.getId()">
-      <img if="event.mayEditComment(config, user, isManager)"
+      <img if="o.class_.mayEditEventComment(o, event, user, isManager)"
            class="clickable iconS" style="float:right" src=":url('edit.svg')"
            title=":_('object_edit')"
            onclick=":'onHistoryEvent(%s,%s,%s,%s)' % \
@@ -161,12 +161,7 @@ class Event(persistent.Persistent):
         '''Returns the formatted version of p_self.comment'''
         comment = self.comment
         if not comment: return empty
-        Escape.xhtml(comment, p=True)
-
-    def mayEditComment(self, config, user, isManager):
-        '''May p_user edit the comment on this event ?'''
-        if not config.model.editHistoryComments: return
-        return isManager or (user.login == self.login)
+        return Escape.xhtml(comment, p=True)
 
     def getId(self):
         '''Return an ID for this history p_event, based on its date.'''
@@ -288,7 +283,7 @@ class Change(Event):
         r = []
         tool = o.tool
         for type in self.diffEntries:
-            msg = self.translate('history_%s' % type, mapping=mapping)
+            msg = o.translate('history_%s' % type, mapping=mapping)
             date = tool.formatDate(self.date)
             r.append('%s: %s' % (date, msg))
         return r
