@@ -64,7 +64,7 @@ class Peer:
 
     # Peer constructor - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
     def __init__(self, url, login=None, password=None, id=None, name=None,
-                 myId=None, myName=None, folder=None):
+                 myId=None, myName=None, folder=None, timeout=10):
         # The URL of the distant site
         self.url = url
         # An optional ID for this distant site
@@ -94,13 +94,17 @@ class Peer:
         # If not, it is not possible to automatically deduce its "addability".
         # If your app uses Refs being "add=False,link=False,composite=False" but
         # are "addable", you must declare them in the following attribute. If
-        # you don't do it, those Refs will be considered as not addable.
-        self.addable = {} # ~{s_className: {s_refFieldName: None}}~
+        # you don't do it, those Refs will be considered as not addable. Another
+        # tricky case: an autoref being add=False,link=False,composite=True
+        # will be considered addable but this could be wrong.
+        self.addable = {} # ~{s_className: {s_refFieldName: b_addable}}~
         # ~~~
         # The following attributes store run-time temporary data structures
         # ~~~
-        # Create the proxy instance representing the distant server
-        self.server = Resource(url, login, password)
+        # Create the proxy instance representing the distant server. The passed
+        # p_timeout, expressed in seconds, will be used for every HTTP request
+        # sent to the peer.
+        self.server = Resource(url, login, password, timeout=timeout)
         # A temporary dict of local objects, keyed by their IDs on the distant
         # site. This is required to reify links between local objects via Refs.
         self.localObjects = {}
