@@ -91,6 +91,13 @@ class Importer:
 
     def addableRef(self, field):
         '''Is this Ref p_field addable ?'''
+        # Check first in the peer config
+        addable = self.peer.addable
+        if addable:
+            fields = addable.get(self.local.class_.name)
+            if fields and field.name in fields:
+                return fields[field.name]
+        # Deduce addability
         if field.add:
             r = True
         elif field.link:
@@ -98,9 +105,7 @@ class Importer:
         elif field.composite:
             r = True
         else:
-            # Check in the peer config
-            addable = self.peer.addable.get(self.local.class_.name)
-            r = addable and (field.name in addable)
+            r = False
         return r
 
     def setRef(self, field):
