@@ -138,6 +138,13 @@ class Buffer:
         lastIndex = subBufferIndexes.pop()
         del self.subBuffers[lastIndex]
 
+    def crunchExpr(self, expr):
+        '''Removes any unnecessary whitespace in this parsed p_expr(ession)'''
+        # Replacing groups of 3 spaces seems to be a wise compromise between
+        # efficient removal of unnecessary spaces and probability of removing
+        # spaces that make sense.
+        return expr.strip().replace('   ', '')
+
     def write(self, something): pass # To be overridden
 
     def getLength(self): pass # To be overridden
@@ -222,7 +229,8 @@ class Buffer:
                 self.write(' %s=%s' % (name, quoteattr(value)))
             else:
                 self.write(' %s="' % name)
-                self.addExpression(value[1:])
+                content = value[1:] if self.pod else self.crunchExpr(value[1:])
+                self.addExpression(content)
                 self.write('"')
         res = None
         if hook:
