@@ -167,8 +167,24 @@ class OdtImporter(DocImporter):
 
 #- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 class PodImporter(DocImporter):
-    '''This class allows to import the result of applying another POD template,
-       into the current POD result.'''
+    '''Imports the result of applying another POD template, into the current POD
+       result.'''
+
+    def mustStream(self):
+        '''Returns "in" if communication with LibreOffice must be performed via
+           streams.'''
+        ren = self.renderer
+        # The default value is the one from the main renderer
+        default = ren.stream
+        # Must we communicate with LO via streams ?
+        stream = (default in (True, 'in')) or \
+                 (default == 'auto' and ren.loPool.server != 'localhost')
+        # If the global result must be streamed, for this sub-pod, stream must
+        # be "in": this way, the output is written on disk, on the distant LO
+        # machine. Then, when we will, via the OdtImporter that will be called
+        # just after this PodImporter, specify the sub-pod to include, the
+        # distant LO will be able to read it from is own disk.
+        return stream and 'in' or default
 
     def init(self, context, pageBreakBefore, pageBreakAfter,
              managePageStyles, resolveFields, forceOoCall):
@@ -178,14 +194,21 @@ class PodImporter(DocImporter):
         self.pageBreakAfter = pageBreakAfter
         self.managePageStyles = managePageStyles
         self.resolveFields = resolveFields
-        # Force LO call if fields must be resolved, or if we are inserting
-        # sub-documents in "duplex" mode. Indeed, in this latter case, we will
-        # need to know the exact number of pages for every sub-document. We will
-        # call LO for that purpose: it will produce correct document statistics
-        # within meta.xml, which is not the case for an ODT document produced by
-        # POD without forcing OO call (stats are those from the document
-        # template and not from the pod result).
-        if (pageBreakAfter == 'duplex') or resolveFields:
+        # Must we communicate with LO via streams ?
+        self.stream = self.mustStream()
+        # Force LO call if:
+        # (a) fields must be resolved ;
+        # (b) if we are inserting sub-documents in "duplex" mode. Indeed, in
+        #     this latter case, we will need to know the exact number of pages
+        #     for every sub-document. We will call LO for that purpose: it will
+        #     produce correct document statistics within meta.xml, which is not
+        #     the case for an ODT document produced by POD without forcing OO
+        #     call (stats are those from the document template and not from the
+        #     pod result) ;
+        # (c) LO is on a distant machine. In that case, forcing OO call allows
+        #     to transmit the sub-pod to the distant machine, ready to be
+        #     incorpotared by the distant LO in the main pod.
+        if pageBreakAfter == 'duplex' or resolveFields or self.stream == 'in':
             force = True
         else:
             # Inherit from the parent renderer's value or get a specific value
@@ -197,32 +220,14 @@ class PodImporter(DocImporter):
                 force = forceOoCall
         self.forceOoCall = force
 
-    def mustStream(self):
-        '''Returns True if communication with LibreOffice must be performed via
-           streams.'''
-        # The default value is the one from the main renderer
-        default = self.renderer.stream
-        # Return the default value if no communication with LO must occur
-        if not self.forceOoCall: return default
-        # Must we communicate with LO via streams ?
-        mustStream = (default in (True, 'in')) or \
-                     ((default == 'auto') and \
-                      (self.renderer.ooServer != 'localhost'))
-        # If the global result must be streamed, for this sub-pod, stream must
-        # be "in": this way, the output is written on disk, on the distant LO
-        # machine. Then, when we will, via the OdtImporter that will be called
-        # just after this PodImporter, specify the sub-pod to include, the
-        # distant LO will be able to read it from is own disk.
-        return mustStream and 'in' or default
-
     def run(self):
         # This feature is only available in the open source version
         if utils.commercial: raise utils.CommercialError()
         r = self.renderer
-        stream = self.mustStream()
         # Define where to store the pod result in the temp folder. If we must
         # stream the result, the temp folder will be on a distant machine, so it
         # must be at the root of the OS temp folder.
+        stream = self.stream
         base = getOsTempFolder() if stream == 'in' else self.getImportFolder()
         resOdt = os.path.join(base, '%s.odt' % getUuid())
         # The POD template is in self.importPath
@@ -235,7 +240,7 @@ class PodImporter(DocImporter):
               forceOoCall=self.forceOoCall,
               managePageStyles=self.managePageStyles,
               resolveFields=self.resolveFields, metadata=False,
-              deleteTempFolder=False)
+              deleteTempFolder=False, loPool=r.loPool)
             renderer.stylesManager.stylesMapping = r.stylesManager.stylesMapping
             # Add this renderer to the list of child renderers on the parent
             r.children[template] = renderer
