@@ -24,6 +24,7 @@ import appy.pod
 from appy import utils
 from appy.xml import Tag
 from appy.pod import PodError
+from appy.pod.lo_pool import LoPool
 from appy.utils.zip import unzip, zip
 from appy.pod.buffers import FileBuffer
 from appy.utils.path import FolderDeleter
@@ -38,25 +39,11 @@ BAD_CTX     = 'Context must be either a dict, a UserDict or an instance.'
 RES_FOLDER  = 'Result file "%s" is a folder, please remove this.'
 RES_EXISTS  = 'Result file "%s" exists.'
 TEMP_W_KO   = 'I cannot create temp folder "%s". %s'
-NO_PY_PATH  = 'Extension of result file is "%s". In order to perform ' \
-              'conversion from ODT to this format we need to call ' \
-              'LibreOffice. But the Python interpreter which runs the ' \
-              'current script does not know UNO, the library that allows to ' \
-              'connect to LibreOffice in server mode. If you can\'t install ' \
-              'UNO in this Python interpreter, you can specify, in parameter ' \
-              '"pythonWithUnoPath", the path to a UNO-enabled Python ' \
-              'interpreter. One such interpreter may be found in ' \
-              '<libreoffice_path>/program.'
-PY_PATH_KO  = '"%s" is not a file. You must here specify the absolute ' \
-              'path of a Python interpreter (.../python, .../python.sh, ' \
-              '.../python.exe, .../python.bat...).'
 R_TYPE_KO   = 'Result "%s" has a wrong extension. Allowed extensions are: "%s".'
-CONV_ERROR  = 'An error occurred during the conversion. %s'
-BAD_LO_PORT = 'Wrong LibreOffice port "%s". Make sure it is an integer.'
-XHTML_ERROR = 'An error occurred while rendering XHTML content.'
-WARN_OD_KO  = 'Warning: your OpenDocument file may not be complete (ie ' \
-              'imported documents may not be present). This is because we ' \
-              'could not connect to LibreOffice in server mode: %s'
+CONV_ERR    = 'An error occurred during the conversion. %s'
+NO_LO_POOL  = 'For producing pod results of type "%s", LibreOffice must be ' \
+              'called in server mode. Specify its server name and port in ' \
+              'Renderer\'s ad hoc attributes.'
 DOC_KO      = 'Please specify a document to import, either with a stream ' \
               '(parameter "content") or with a path (parameter "at").'
 DOC_FMT_KO  = 'POD was unable to deduce the document format. Please specify ' \
@@ -140,7 +127,7 @@ class Renderer:
       resolveFields=False, expressionsHolders=defaultExpressionsHolders,
       metadata=True, pdfOptions='ExportNotes=True', csvOptions=None,
       deleteTempFolder=True, protection=False, pageStart=1, tabbedCR=False,
-      fonts=None):
+      fonts=None, loPool=None):
         '''Base on a document template (whose path is in p_template), which is
            an ODT or ODS file containing special expressions and statements
            written in Python, this renderer generates an ODT file (whose path is
@@ -164,6 +151,9 @@ class Renderer:
         # server named p_ooServer, listening on port p_ooPort. If you run
         # several LibreOffice servers, p_ooPort may specify a list of ports. In
         # that case, pod will load-balance requests to the appropriate server.
+        # Note that, when using such a "pool" of LO servers, they all must
+        # reside on the same machine (p_ooServer); pod assumes they are all
+        # up-and-running.
 
         # p_stream dictates the communication between the renderer and LO.
         # ----------------------------------------------------------------------
@@ -207,7 +197,10 @@ class Renderer:
 
         # If p_raiseOnError is False (the default value), any error encountered
         # during the generation of the result file will be dumped into it, as a
-        # Python traceback within a note. Else, the error will be raised.
+        # Python traceback within a note. Else, the error will be raised. If the
+        # template is an ODS template, exceptions cannot be dumped as inner
+        # notes: p_raiseOnError is forced to True, whatever value you may have
+        # passed to the Renderer.
 
         # When, in the process of converting a chunk of XHTML code to ODF, a
         # "img" tag is encountered, POD performs a HTTP GET to retrieve it. If
@@ -340,20 +333,22 @@ class Renderer:
         # like:
         #                      fc-list :lang=en family
 
+        # Please leave p_loPool attribute to None. A LO pool is a data structure
+        # being internal to pod, allowing to communicate with LO. This is only
+        # used by pod itself, when a main Renderer instance needs to create a
+        # sub-Renderer instance, ie, for importing a sub-pod into a main pod.
+
         self.template = template
         self.templateType = self.getTemplateType(template)
         self.result = result
-        self.resultType = os.path.splitext(result)[1].strip('.')
-        self.contentXml = None # Content (string) of content.xml
-        self.stylesXml = None # Content (string) of styles.xml
+        self.resultType  = os.path.splitext(result)[1].strip('.')
+        self.contentXml  = None # Content (string) of content.xml
+        self.stylesXml   = None # Content (string) of styles.xml
         self.manifestXml = None # Content (string) of manifest.xml
-        self.metaXml = None # Content (string) of meta.xml
-        # Manages the styles defined into the ODT template
-        self.tempFolder = None
+        self.metaXml     = None # Content (string) of meta.xml
+        self.tempFolder  = None
         self.env = None
-        self.pythonWithUnoPath = pythonWithUnoPath
-        self.ooServer = ooServer
-        self.ooPort = self.manageLoPort(ooPort)
+        self.loPool = loPool or LoPool.get(pythonWithUnoPath, ooServer, ooPort)
         self.stream = stream
         # p_forceOoCall may be forced to True
         self.forceOoCall = forceOoCall or bool(optimalColumnWidths) or \
@@ -426,10 +421,9 @@ class Renderer:
         self.stylesManager.stylesMapping = smap
 
     # Attributes to clone to a sub-renderer when using m_clone hereafter
-    cloneAttributes = ('pythonWithUnoPath', 'ooServer', 'ooPort', 'html',
-      'raiseOnError', 'findImage', 'rotateImages', 'stylesTemplate',
-      'optimalColumnWidths', 'distributeColumns', 'expressionsHolders',
-      'protection', 'tabbedCR', 'fonts')
+    cloneAttributes = ('html', 'raiseOnError', 'findImage', 'rotateImages',
+      'stylesTemplate', 'optimalColumnWidths', 'distributeColumns',
+      'expressionsHolders', 'protection', 'tabbedCR', 'fonts')
 
     def clone(self, template, context, result, **params):
         '''Creates another Renderer instance, similar to p_self, but for
@@ -444,15 +438,6 @@ class Renderer:
         # Create and return the clone
         return Renderer(template, context, result, **params)
 
-    def manageLoPort(self, loPort):
-        '''Ensure the specified LO port (p_loPort) is valid. If it is a list of
-           ports, create the data structure allowing to manage load-balancing
-           between LO servers.'''
-        port = loPort or 2002
-        if not isinstance(port, int):
-            raise PodError(BAD_LO_PORT % str(port))
-        return port
-
     def formatFinalizeFunction(self, fun):
         '''Standardize "finalize function" p_fun as a list of functions'''
         if not fun: return
@@ -487,7 +472,7 @@ class Renderer:
           'columnBreak': self.insertColumnBreak,
           # Variables to use for representing pod-reserved chars
           'PIPE': '|', 'SEMICOLON': ';'})
-        # Developer, forget the following line
+        # Insert the context as an entry of itself
         if '_ctx_' not in r: r['_ctx_'] = r
         return r
 
@@ -808,7 +793,7 @@ class Renderer:
     def importPod(self, content=None, at=None, format='odt', context=None,
                   pageBreakBefore=False, pageBreakAfter=False,
                   managePageStyles='rename', resolveFields=False,
-                  forceOoCall=INHERIT):
+                  forceOoCall=False):
         '''Implements the POD statement "do... from pod"'''
 
         # Similar to m_importDocument, but allows to import the result of
@@ -833,6 +818,12 @@ class Renderer:
         # Is there a pod template defined ?
         if not content and not at: raise PodError(DOC_KO)
         imp = importers.PodImporter(content, at, format, self)
+        # Importing a sub-pod into a main pod is done by defining, in the main
+        # pod, a section linked to an external file being the sub-pod result.
+        # Then, LibreOffice is asked to "resolve" such sections = replacing the
+        # section with the content of the linked file. This task is done by
+        # LibreOffice itself and triggered via a UNO command. Consequently,
+        # Renderer attribute "forceOoCall" must be forced to True in that case.
         self.forceOoCall = True
         # Define the context to use: either the current context of the current
         # POD renderer, or p_context if given.
@@ -990,89 +981,6 @@ class Renderer:
                 FolderDeleter.delete(self.tempFolder)
             raise po
 
-    def callLibreOffice(self, resultName, outputName=None, format=None):
-        '''Call LibreOffice in server mode to convert or update the result'''
-        # Here are the valid combinations for parameter's values.
-        # ----------------------------------------------------------------------
-        # no outputName | The converter will produce a result whose name is
-        #   no format   | p_resultName whose file extension has been replaced
-        #               | with the one specified in self.resultType.
-        # ----------------------------------------------------------------------
-        # no outputName | Idem, but the output format is forced to p_format
-        #    format     | instead of using self.resultType.
-        # ----------------------------------------------------------------------
-        #  outputName   | The converter will produce a result whose name is
-        #  no format    | p_outputName. The output format will depend on
-        #               | p_outputName's file extension.
-        # ----------------------------------------------------------------------
-        loOutput = ''
-        # Determine the "result" to ask to LibreOffice
-        if outputName:
-            result = outputName
-            resultType = os.path.splitext(result)[-1][1:]
-        else:
-            result = format or self.resultType
-            resultType = result
-        # Get CSV options if we must produce a CSV file
-        if resultType == 'csv':
-            csvOptions = (self.csvOptions or CsvOptions.default).asString()
-        else:
-            csvOptions = None
-        try:
-            try:
-                from appy.pod.converter import Converter
-                try:
-                    Converter(resultName, result, self.ooServer, self.ooPort,
-                      self.stylesTemplate, self.optimalColumnWidths,
-                      self.distributeColumns, self.script, self.resolveFields,
-                      self.pdfOptions, csvOptions, self.ppp, self.stream,
-                      self.pageStart).run()
-                except Converter.Error as ce:
-                    raise PodError(CONV_ERROR % str(ce))
-            except ImportError:
-                # I do not have UNO. So try to launch a UNO-enabled Python
-                # interpreter which should be in self.pythonWithUnoPath.
-                pyPath = self.pythonWithUnoPath
-                if not pyPath:
-                    raise PodError(NO_PY_PATH % resultType)
-                if not os.path.isfile(pyPath):
-                    raise PodError(PY_PATH_KO % pyPath)
-                convScript = '%s/converter.py' % \
-                             os.path.dirname(appy.pod.__file__)
-                cmd = [pyPath, convScript, resultName, result,
-                       '-e', self.ooServer, '-p', str(self.ooPort)]
-                add = cmd.append
-                if self.stylesTemplate:
-                    add('-t'); add(self.stylesTemplate)
-                if self.optimalColumnWidths:
-                    add('-o'); add(str(self.optimalColumnWidths))
-                if self.distributeColumns:
-                    add('-d'); add(str(self.distributeColumns))
-                if self.script:
-                    add('-s'); add(self.script)
-                if self.resolveFields:
-                    add('-r'); add(self.resolveFields)
-                if self.pdfOptions:
-                    add('-f'); add(self.pdfOptions)
-                if csvOptions:
-                    add('-i'); add(csvOptions)
-                if self.ppp: add('-c')
-                if self.stream != 'auto':
-                    add('-a'); add(str(self.stream))
-                if self.pageStart > 1:
-                    add('-g'); add(str(self.pageStart))
-                out, loOutput = utils.executeCommand(cmd)
-        except PodError as pe:
-            # When trying to call LO in server mode for producing ODT or ODS
-            # (=forceOoCall=True), if an error occurs we have nevertheless
-            # an ODT or ODS to return to the user. So we produce a warning
-            # instead of raising an error.
-            if (resultType in self.templateTypes) and self.forceOoCall:
-                print(WARN_OD_KO % str(pe))
-            else:
-                raise pe
-        return loOutput
-
     def getTemplateType(self, template):
         '''Identifies the type of this POD p_template (ods or odt). If
            p_template is a string, it is a file name: simply get its extension.
@@ -1088,6 +996,12 @@ class Renderer:
             r = 'ods' if sbytes.startswith(utils.mimeTypes['ods']) else 'odt'
         return r
 
+    def callLibreOffice(self, resultName, format=None, outputName=None):
+        '''Call LibreOffice in server mode to convert or update the result'''
+        if self.loPool is None:
+            raise PodError(NO_LO_POOL % resultType)
+        return self.loPool(self, resultName, format, outputName)
+
     def finalize(self):
         '''Re-zip the result and potentially call LibreOffice if target format
            is not among self.templateTypes or if forceOoCall is True.'''
@@ -1135,14 +1049,14 @@ class Renderer:
                                   'result.%s' % self.templateType)
         resultType = self.resultType
         zip(resultName, self.unzipFolder, odf=True)
-        if (resultType in self.templateTypes) and not self.forceOoCall:
+        if resultType in self.templateTypes and not self.forceOoCall:
             # Simply move the ODT result to the result
             os.rename(resultName, self.result)
         else:
             if resultType not in FILE_TYPES:
                 raise PodError(R_TYPE_KO % (self.result, FILE_TYPES.keys()))
             # Call LibreOffice to perform the conversion or document update
-            output = self.callLibreOffice(resultName, self.result)
+            output = self.callLibreOffice(resultName, outputName=self.result)
             # I (should) have the result in self.result
             if not os.path.exists(self.result):
                 if resultType in self.templateTypes:
@@ -1151,5 +1065,5 @@ class Renderer:
                     # "raw" pod result that exists in "resultName".
                     os.rename(resultName, self.result)
                 else:
-                    raise PodError(CONV_ERROR % output)
+                    raise PodError(CONV_ERR % output)
 #- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
