@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
 #- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-# Copyright (C) 2007-2020 Gaetan Delannay
+# Copyright (C) 2007-2021 Gaetan Delannay
 
 # This file is part of Appy.
 
@@ -25,13 +25,13 @@ import re, xml.sax, math
 
 from appy.pod import *
 from appy.xml.escape import Escape
+from appy.utils.inject import Injector
 from appy.xml import Environment, Parser
 from appy.utils import formatNumber, addPair
 from appy.pod.odf_parser import OdfEnvironment
 from appy.utils.string import WhitespaceCruncher
-from appy.pod.doc_importers import px2cm, getUuid
 from appy.ui.css import CssStyles, CssValue, px2cm
-from appy.pod.styles_manager import Style, BulletedProperties,NumberedProperties
+from appy.pod.styles_manager import Style,BulletedProperties,NumberedProperties
 
 # Tags for which there is a direct correspondance between HTML and ODF
 h = 'text:h'
@@ -748,7 +748,7 @@ class XhtmlEnvironment(Environment):
     def getUniqueStyleName(self, type):
         '''Gets a unique name for an element of some p_type (a table, a
            list).'''
-        return '%s%s' % (type.capitalize(), getUuid(removeDots=True))
+        return getUuid(removeDots=True, prefix=type.capitalize())
 
     def getCurrentTag(self, isList=False):
         '''Gets the element that is on the top of p_self.currentTags or
@@ -826,12 +826,8 @@ class XhtmlEnvironment(Environment):
             # Manage cells' borders
             border = table.props.border
             if border is None:
-                border = table.border
-                if not border:
-                    xhtmlElem.cssStyles.add('border', '0')
-                # Else, the default will be "1"
-            else:
-                xhtmlElem.cssStyles.add('border', border)
+                border = table.border and '0.05pt solid #000000' or '0'
+            xhtmlElem.cssStyles.add('border', border)
             # Manage cells' spacing
             spacing = table.borderSpacing
             if spacing:
@@ -844,7 +840,7 @@ class XhtmlEnvironment(Environment):
                (xhtmlElem.elem in PARA_TAGS):
                 # The enclosed "p" must get the td's inner styles
                 if parent.innerStyle:
-                    xhtmlElem.cssStyles.addClass(parent.innerStyle)
+                    xhtmlElem.cssStyles.addClass(parent.innerStyle,append=False)
                 if parent.innerCssStyles:
                     xhtmlElem.cssStyles.merge(parent.innerCssStyles)
         # Get the base ODF style for this p_xhtmlElem
@@ -1201,8 +1197,11 @@ class XhtmlParser(Parser):
                  '<text:note-citation>%s</text:note-citation><text:note-body>'%\
                  (nb, nb))
         elif elem == 'tab':
-            # Another inexistent tag in HTML, useful for managing tabs
+            # Another inexistent tag in HTML, for managing tabs
             dump('<text:tab/>')
+        elif elem == 'cs':
+            # Yet another one, for managing consecutive spaces
+            dump('<text:s text:c="%s"/>' % attrs['n'])
         elif elem in IGNORABLE_TAGS:
             e.ignore = True
 
@@ -1276,7 +1275,7 @@ class XhtmlPreprocessor:
        it uses a SAX parser to do its job. This preprocessor ensures it is the
        case, by applying some modifications to this input.'''
 
-    # Regular expression representing a HTML void tag
+    # Regular expression representing an HTML void tag
     voidTags = ('area', 'base', 'br', 'col', 'hr', 'img', 'input', 'link',
                 'meta', 'param', 'command', 'keygen', 'source')
     voidTag = re.compile('<(%s)([^>]*?)(/)?\s*>' % '|'.join(voidTags), re.S)
@@ -1284,6 +1283,15 @@ class XhtmlPreprocessor:
     # Regular expression representing a "pre" tag
     preTag = re.compile('<pre.*?>(.*?)</pre>', re.S)
 
+    # Regular expression representing a group of consecutive spaces within a
+    # "pre" tag. Indeed, such groups, within the ODF result, must be converted
+    # to "text:s" tags.
+    preSpaces = re.compile(' {2,}')
+
+    # A "pre" para will get CSS class "pre", in order to be style-mapped
+    prePara = '<p class="pre">'
+    preParaN = '</p>%s' % prePara
+
     @classmethod
     def patchTag(class_, match):
         '''Add the trailing slash if absent'''
@@ -1292,30 +1300,42 @@ class XhtmlPreprocessor:
         return '<%s%s/>' % (match.group(1), match.group(2))
 
     @classmethod
-    def replacePreTag(class_, match):
-        '''Replace the matched "pre" tag by a "table" tag'''
-        return '<table style="margin: 15px 0"><tr><td>' \
-               '<p>%s</p></td></tr></table>' % \
-               match.group(1).replace('\n', '</p><p>')
+    def replacePreSpaces(class_, match):
+        '''Replace every p_match(ed) sequence of consecutive spaces with a "cs"
+           tag.'''
+        return '<cs n="%d"/>' % len(match.group(0))
 
     @classmethod
-    def preprocess(class_, s, html=False, pre=True):
+    def replacePreTag(class_, match):
+        '''Replace the matched "pre" tag by a "table" tag'''
+        # Within the content of the "pre" tag, replace consecutive blanks with
+        # "cs" tags. a "cs" tag ("cs" stands for "consecutive spaces") does not
+        # exist in XHTML: it has been invented in Appy for converting it to ODF
+        # "text:s" tags.
+        content = class_.preSpaces.sub(class_.replacePreSpaces, match.group(1))
+        return '<table><tr><td>%s%s</p></td></tr></table>' % \
+               (class_.prePara, content.replace('\n', class_.preParaN))
+
+    @classmethod
+    def preprocess(class_, s, html=False, pre=True, inject=False):
         '''Converts string p_s to valid XHTML and r_eturns it'''
+
         # If p_html is True, p_s is supposed to be valid HTML: void tags must be
-        # converted to XHTML's self-closing start tags.
-        # ~~~
-        # If p_pre is True, "pre" tags are converted to one-cell tables
-        # ~~~
+        # converted to XHTML's self-closing start tags. If p_pre is True, "pre"
+        # tags are converted to one-cell tables. If p_inject is True,
+        # injections, as defined by the appy Rich field, are performed.
+
         if s is None: s = ''
         # Surround p_s with a tag in order to get a XML-compliant file (we need
         # a root tag). We also remove special blank chars that produce SAX
         # parsing errors.
         s = '<p>%s</p>' % s.replace('\f', '').replace('\v', '')
-        # Convert, when required, conversion of HTML's void tags to XHTML's
-        # self-closing start tags.
-        #if html: s = class_.voidTag.sub(class_.patchTag, s)
+        # Convert, when required, HTML void tags to XHTML self-closing tags
         if html: s = class_.voidTag.sub(class_.patchTag, s)
-        if pre:  s = class_.preTag.sub(class_.replacePreTag, s)
+        # Integrate, when required, chunks of code files
+        if inject: s = Injector.run(s)
+        # Convert, when required, "pre" tags to one-cell tables
+        if pre: s = class_.preTag.sub(class_.replacePreTag, s)
         return s
 
 #- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -1324,9 +1344,11 @@ class Xhtml2OdtConverter:
     verbose = False
 
     def __init__(self, s, stylesManager, localStylesMapping, keepWithNext,
-                 keepImagesRatio, imagesMaxWidth, renderer, html, unwrap):
+                 keepImagesRatio, imagesMaxWidth, renderer, html, inject,
+                 unwrap):
         self.renderer = renderer
-        self.xhtmlString = XhtmlPreprocessor.preprocess(s, html=html)
+        self.xhtmlString = XhtmlPreprocessor.preprocess(s, html=html,
+                                                        inject=inject)
         self.stylesManager = stylesManager
         self.localStylesMapping = localStylesMapping
         self.odtChunk = None
