@@ -94,7 +94,6 @@ class Px:
         self.hook = hook
         # Is there some (XML, XHTML...) prologue to dump ?
         self.prologue = prologue
-        
         # PX-specific CSS and JS code
         self.css = self.compact(css)
         self.js = self.compact(js)
@@ -106,6 +105,23 @@ class Px:
         if not self.isMethod:
             self.parse()
 
+    def clone(self, keepTemplate=True):
+        '''Create a clone from (my)p_self'''
+        # p_keepTemplate offers the possibility to produce p_self's variant,
+        # being unwrapped from its template.
+        if keepTemplate:
+            template = self.template
+            hook = self.hook
+        else:
+            template = None
+            hook = None
+        r = Px(self.content, partial=self.partial, template=template, hook=hook,
+               prologue=self.prologue)
+        # Avoid re-compacting CSS and JS
+        r.css = self.css
+        r.js = self.js
+        return r
+
     def parse(self):
         '''Parses self.content and create the structure corresponding to this
            PX.'''
@@ -129,7 +145,7 @@ class Px:
         r = []
         for line in s.split('\n'):
             line = line.strip()
-            if not line.startswith('//'):
+            if line and not line.startswith('//'):
                 r.append(line)
         return '\n'.join(r)
 
@@ -252,8 +268,11 @@ class Px:
         self.name = name
         self.profiler = profiler
 
-    # Literals to convert via method p_convertValue below
-    literals = {'True': True, 'False': False, 'None': None}
+    # Literals to convert via method p_convertValue below. Although not being
+    # purely Pythonic, literals 'true' and 'false' are converted to Python
+    # booleans.
+    literals = {'True': True, 'False': False, 'None': None,
+                'true': True, 'false': False}
 
     @classmethod
     def convertValue(class_, value, tool):
@@ -299,10 +318,7 @@ class Px:
             # Add entry "class_"
             context.class_ = tool.model.classes.get(req.className)
         if 'search' in req:
-            ui = tool.Search.get(req.search, tool, context.class_, context)
-            context.uiSearch = ui
-            context.resultModes = ui.getModes()
-            context.mode = ui.getMode()
+            tool.Search.initContext(req.search, tool, context)
 
     @classmethod
     def createContext(class_, traversal, layout, Quote):
