@@ -76,7 +76,7 @@ class PxParser(Parser):
         Parser.__init__(self, env, caller)
 
     def startElement(self, elem, attrs):
-        '''A start p_elem with p_attrs is encountered in the PX.'''
+        '''A start p_elem with p_attrs is encountered in the PX'''
         e = self.env
         self.currentTag = elem
         # See if we have a PX attribute among p_attrs
@@ -89,7 +89,9 @@ class PxParser(Parser):
                     e.addSubBuffer()
                     found = True
                 # Add the action
-                e.currentBuffer.createPxAction(elem, name, attrs[name])
+                buffer = e.currentBuffer
+                content = buffer.crunchExpr(attrs[name])
+                buffer.createPxAction(elem, name, content)
         if e.isActionElem(elem):
             # Add a temp element in the buffer (that will be unreferenced
             # later). This way, when encountering the corresponding end element,
@@ -102,24 +104,27 @@ class PxParser(Parser):
             # "selected" or "checked".
             hook = None
             ignorableAttrs = self.pxAttributes
+            buffer = e.currentBuffer
             for name in self.noDumpTags:
-                if (name in attrs) and attrs[name].startswith(':'):
-                    hook = (name, attrs[name][1:])
+                if name in attrs and attrs[name].startswith(':'):
+                    hook = (name, buffer.crunchExpr(attrs[name][1:]))
                     ignorableAttrs += (name,)
                     break
-            e.currentBuffer.dumpStartElement(elem, attrs,
-                ignoreAttrs=ignorableAttrs, noEndTag=elem in SELF_CLOSING,
-                hook=hook, renamedAttrs=self.renamedAttributes)
+            buffer.dumpStartElement(elem, attrs, ignoreAttrs=ignorableAttrs,
+                                    noEndTag=elem in SELF_CLOSING, hook=hook,
+                                    renamedAttrs=self.renamedAttributes)
 
     def endElement(self, elem):
         e = self.env
         # Manage the potentially collected Python expression in
         # e.currentContent.
         if e.currentContent:
-            e.currentBuffer.addExpression(e.currentContent)
+            buffer = e.currentBuffer
+            content = buffer.crunchExpr(e.currentContent)
+            buffer.addExpression(content)
             e.currentContent = ''
         # Dump the end element into the current buffer
-        if (elem != 'x') and (elem not in SELF_CLOSING):
+        if elem != 'x' and elem not in SELF_CLOSING:
             e.currentBuffer.dumpEndElement(elem)
         # If this element is the main element of the current buffer, we must
         # pop it and continue to work in the parent buffer.
@@ -137,10 +142,10 @@ class PxParser(Parser):
         if not e.currentContent and content.startswith(':'):
             # This content is not static content to dump as-is into the result:
             # it is a Python expression.
-            e.currentContent += content[1:]
+            e.currentContent += content[1:].rstrip('\n')
         elif e.currentContent:
-            # We continue to dump the Python expression
-            e.currentContent += content
+            # Continue to dump the Python expression
+            e.currentContent += content.rstrip('\n')
         else:
             # Remove blanks which are there only for improving PX's readability
             if content == ' ':
