@@ -63,6 +63,10 @@ class Config:
         # The version of HTTP in use, as a float value. Currently, 1.0 and 1.1
         # are supported.
         self.httpVersion = 1.1
+        # The value of the "SameSite" attribute for cookies. Can be "Lax" or
+        # "Strict". More info on https://developer.mozilla.org/en-US/docs/Web/
+        #                         HTTP/Headers/Set-Cookie/SameSite
+        self.sameSite = 'Lax'
         # Configuration for static content (set by m_set below)
         self.static = None
         # The size of the queue as defined on the server socket, passed as
