@@ -3,7 +3,7 @@
    respect of security rules defined: workflows, permissions, etc.'''
 
 #- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-# Copyright (C) 2007-2020 Gaetan Delannay
+# Copyright (C) 2007-2021 Gaetan Delannay
 
 # This file is part of Appy.
 
@@ -36,6 +36,8 @@ from appy.model.fields.password import Password
 # Errors - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 KO_LOG_TFM  = 'Invalid value "%s" for attribute "loginTransform".'
 KO_PERM     = '%s "%s": "%s" disallowed.'
+AUTH_KO     = 'Authentication failed with login %s.'
+AUTH_OK     = 'Logged in.'
 
 #- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 class Config:
@@ -71,6 +73,12 @@ class Config:
         # authentication for achieving single-sign-on (SSO), place an instance
         # of appy.server.sso.Config in the field below.
         self.sso = None
+        # If the following attribute is not None, a warning about accepting
+        # cookies will be shown until the user accepts it. His acceptance will
+        # be stored in a cookie named "cookiesAccepted". Attribute
+        # "cookieWarning" must contain the name of an attribute on the tool,
+        # that must store the URL of a page displaying the privacy policy.
+        self.cookieWarning = False
 
     def getLdap(self):
         '''Returns the LDAP config if it exists'''
@@ -117,6 +125,14 @@ class Guard:
     def __init__(self, handler):
         # The handler that has instantiated this guard
         self.handler = handler
+        # Info about the currently selected authentication context
+        self.authContext = None
+        # A human-readable name for this context
+        self.authContextName = None
+        # If the authentication context corresponds to a Appy object, the
+        # following attribute will get this object once per request and store it
+        # here.
+        self.authObject = None
         # Unwrap some useful objects
         self.model = handler.server.model
         self.config = handler.server.config
@@ -125,10 +141,14 @@ class Guard:
         # Remember that this user hits the server now
         if not handler.fake:
             handler.onlineUsers[self.user.login] = DateTime()
-        # Info about the currently selected authentication context
-        self.authContext = None
         # Cache info about this user
         self.cache()
+        # Has the user accepted the cookie warning ?
+        if self.config.security.cookieWarning:
+            self.cookiesAccepted = handler.req.cookiesAccepted == '1'
+        else:
+            # We don't care about accepting cookies
+            self.cookiesAccepted = True
 
     def cache(self):
         '''Pre-compute, for performance, heavily requested information about the
@@ -190,7 +210,8 @@ class Guard:
     def allows(self, o, permission='read', raiseError=False):
         '''Has the user p_permission on p_o ?'''
         r = self.user.hasPermission(permission, o)
-        if not r and raiseError: raise Unauthorized()
+        if not r and raiseError:
+            raise Unauthorized(KO_PERM % (o.class_.name, o.id, permission))
         return r
 
     def mayAct(self, o):
@@ -223,7 +244,8 @@ class Guard:
         # An additional, user-defined condition, may refine the base permission
         r = multicall(o, 'mayEdit', True)
         if not r and raiseError:
-            o.raiseUnauthorized(KO_PERM % (o.class_.name, o.id, permission))
+            method = '%s::mayEdit' % o.class_.name
+            raise Unauthorized(KO_PERM % (method, o.id, permission))
         return r
 
     def mayView(self, o, permission='read', raiseError=False):
@@ -235,7 +257,8 @@ class Guard:
         # An additional, user-defined condition, may refine the base permission
         r = multicall(o, 'mayView', True)
         if not r and raiseError:
-            o.raiseUnauthorized(KO_PERM % (o.class_.name, o.id, permission))
+            method = '%s::mayView' % o.class_.name
+            raise Unauthorized(KO_PERM % (method, o.id, permission))
         return r
 
     #- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -252,12 +275,13 @@ class Guard:
             # Authentication failed
             label = 'login_ko'
             success = False
-            msg = 'Authentication failed with login %s.' % (req.login or '')
+            login = req.login.strip() if req.login else ''
+            msg = AUTH_KO % login
         else:
             # Authentication succeeded
             label = 'login_ok'
             success = True
-            msg = 'Logged in.'
+            msg = AUTH_OK
         # Log the action
         tool.log(msg)
         # Redirect the user to the appropriate page
@@ -301,6 +325,19 @@ class Guard:
         if user.source == 'sso': return self.config.security.sso.logoutUrl
         return '%s/guard/leave' % tool.url
 
+    def getLoginUrl(self, ctx):
+        '''When discreet logins are in use, compute the JS code or link allowing
+           to open the login box as a popup or redirect the user to tool/home,
+           depending on the config.'''
+        if ctx.cfg.discreetLogin == 'home':
+            # "discreet" may hold "home" or "homes". Attribue "stay" will force
+            # to stay on this page. Indeed, without it, in "discreet login"
+            # mode, tool/home[s] redirects to tool/public.
+            r = '%s/%s?stay=1' % (ctx.tool.url, ctx.cfg.home)
+        else:
+            r = 'javascript:toggleLoginBox(true)'
+        return r
+
     def getSelfRegisterJS(self, tool):
         '''Gets the JS code allowing to create a User instance for the purpose
            of self-registering.'''
@@ -356,8 +393,11 @@ class Guard:
         login = req.login
         token = req.token
         _ = tool.translate
+        siteUrl = tool.computeHomePage()
+        # Stop if the URL was called with missing parameters
+        if not login or not token:
+            return tool.goto(siteUrl, _('wrong_password_reinit'))
         # Check if such token exists in temp folder
-        siteUrl = tool.siteUrl
         tokenFile = Path(putils.getOsTempFolder()) / login
         if tokenFile.exists():
             with tokenFile.open() as f:
@@ -372,7 +412,7 @@ class Guard:
                     # Send the new password by email
                     recipient = user.getMailRecipient()
                     subject = _('new_password')
-                    map = {'password': newPassword, 'siteUrl': siteUrl}
+                    map = {'password': newPassword, 'siteUrl': tool.siteUrl}
                     body = _('new_password_body', mapping=map, asText=True)
                     tool.sendMail(recipient, subject, body)
                     tokenFile.unlink()
@@ -384,6 +424,10 @@ class Guard:
     # PXs
     #- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 
+    # A custom zone, at the bottom of pxLogin, allowing an app to add custom
+    # content.
+    pxLoginBottom = Px('')
+
     # The login form
     pxLogin = Px('''
      <!-- Popup for reinitializing the password -->
@@ -406,24 +450,26 @@ class Guard:
      <!-- The login box -->
      <div class="loginBox"
           var="cfg=config.security;
-               discreet=config.ui.discreetLogin"
-          style=":'display:%s' % ('none' if discreet else 'block')">
+               discreet=config.ui.discreetLogin;
+               display='none' if discreet and not req.stay else 'block'"
+          style=":'display:%s' % display">
 
       <!-- Allow to hide the box when relevant -->
-      <img if="discreet" src=":url('close.svg')" style="float:right"
+      <img if="discreet == True" src=":url('close.svg')" style="float:right"
            onclick="toggleLoginBox(false)" class="clickable iconXS"/>
 
-      <h1>:_('app_name')</h1>
-      <center>:_('please_connect')</center>
+      <div align="center"><img src=":url('loginLogo')"/></div>
+      <h1>::_('app_name')</h1>
+      <center class="sub">:_('please_connect')</center>
       <div class="loginSpace"></div>
       <form id="loginForm" name="loginForm" method="post" class="login"
             action=":'%s/guard/enter' % tool.url">
 
        <!-- Login fields  -->
        <center><input type="text" name="login" id="login" value=""
-                   placeholder=":_('app_login')" class="loginField"/></center>
+                   placeholder=":_('app_login')"/></center>
        <center><input type="password" name="password" id="password"
-                placeholder=":_('app_password')" class="loginField"/></center>
+                placeholder=":_('app_password')"/></center>
 
        <!-- The authentication context -->
        <x var="ctx=cfg.authContext"
@@ -437,9 +483,9 @@ class Guard:
        <input type="hidden" name="goto" value=":req.get('goto', '')"/>
 
        <!-- The "submit" button -->
-       <div align="right">
+       <div class="submitLogin">
          <input type="submit" name="submit" var="label=_('app_connect')"
-                class="loginSubmit" value=":label" alt=":label"/></div>
+                value=":label" alt=":label"/></div>
 
        <!-- Forgot password ? -->
        <div class="lostPassword" if="cfg.activateForgotPassword">
@@ -448,12 +494,15 @@ class Guard:
        </div>
 
        <!-- Link to self-registration -->
-       <p if="cfg.selfRegister">
+       <div if="cfg.selfRegister" class="autoRegister">
         <span style="padding-right: 10px">:_('want_register')</span>
           <a style="font-size: 90%" class="clickable"
              onclick=":guard.getSelfRegisterJS(tool)">:_('app_register')</a>
-       </p>
+       </div>
       </form>
+
+      <!-- Custom zone -->
+      <x>:guard.pxLoginBottom</x>
      </div>''',
 
      js='''
@@ -471,29 +520,63 @@ class Guard:
 
      css='''
       .loginBox {
-         border: 2px solid #9fa8c1; padding: 35px; color: #335256;
-         background-color:white; width: 333px; height: 373px;
-         position: absolute; top: 50%; left: 50%; z-index: 10;
-         transform: translate(-50%,-50%); -ms-transform: translate(-50%,-50%);
-         box-shadow: 0 4px 8px 0 rgba(160, 104, 132, 0.2),
-                     0 6px 20px 0 rgba(0, 0, 0, 0.19)
+         border:|loginBorder| |loginColorPh|; padding:35px; color:|darkColor|;
+         background-color:|boxBgColor|; position:absolute; top:|loginTop|;
+         left:50%; z-index:10; transform:translate(-50%,-50%);
+         box-shadow:|loginShadow|; border-radius: |loginBorderRadius|
       }
-      .loginBox a, .loginBox a,:visited {
-         font-weight: bold; letter-spacing: 1px }
-      .loginBox h1 { padding-bottom: 0; text-align: center }
-      .loginField { background-color: #4a5f73 !important;
-         width: 310px !important; padding: 12px !important;
-         margin: 6px 0  !important; color: #f3f3f7 }
-      .loginSubmit { margin: 22px 0; padding: 7px }
-      .lostPassword { padding: 10px 0 }
+      .loginBox a, .loginBox a:visited { font-weight:bold; letter-spacing:1px }
+      .loginBox h1 { padding-bottom:0; margin-bottom:3px; text-align:center;
+                     font-size:160%; font-weight: |loginTitleWeight| }
+      .loginBox .sub { font-size:120% }
+      #loginForm input {
+        background-color:|loginBgColor|; width:|loginWidth|; border:none;
+        padding:|loginPadding|; margin:|loginMargin|; color:|loginColor| }
+      .submitLogin { text-align:|submitAlign|
+      }
+      #loginForm input[type=submit] {
+        color:|submitColor|; width:|submitWidth|; height:|submitHeight|;
+        background:|submitBgColor| |submitBgUrl| no-repeat center left;
+        border-radius:|submitBgRadius|; font-weight:|submitWeight|;
+        margin-top:|submitTop|; text-transform:uppercase;
+        padding:|submitPadding|
+      }
+      .lostPassword { padding:10px 0; font-size:80%; text-align:|loginAlign| }
+      .autoRegister { text-align:|loginAlign| }
+
       /* Placeholder color for the login form */
-      .loginBox ::-webkit-input-placeholder {
-        color: white; font-weight: bold }
-      .loginBox ::-moz-placeholder {
-        color: white; font-weight: bold; font-size:120% }
-      .loginBox :-ms-input-placeholder {
-        color: white; font-weight: bold; font-size: 120% }
-      .loginSpace { height: 35px }
-      #rlogin { color: white }
+      .loginBox ::placeholder, .loginBox ::-webkit-input-placeholder {
+        color:|loginColorPh|; font-weight:bold; text-transform:uppercase }
+      .loginSpace { height:35px }
+      #rlogin { color:white }
      ''')
+
+    # Warning about using cookies  - - - - - - - - - - - - - - - - - - - - - - -
+
+    pxWarnCookies = Px('''
+     <div class="cookieWarn">
+      <div>
+       <x>:_('cookie_warn')</x>
+       <a href=":getattr(tool, config.security.cookieWarning)">:_('cookie_read')
+       </a>
+       <input type="button" value=":_('cookie_accept')"
+              onclick="setAcceptCookie(this)"/>
+      </div>
+     </div>
+    ''',
+
+    css='''
+      .cookieWarn { background-color:lightgrey; width:100%; position:absolute;
+                    bottom:0; font-size:90%; z-index: 100 }
+      .cookieWarn div { padding: 7px 15px }
+      .cookieWarn a { margin: 0 10px; text-decoration: underline }
+      .cookieWarn input { display:inline; background-color:#b5b5b5 }
+    ''',
+
+    js='''
+      function setAcceptCookie(button) {
+        createCookie('cookiesAccepted', '1');
+        button.parentNode.parentNode.style.display = 'none';
+      }'''
+    )
 #- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
