@@ -392,8 +392,9 @@ class HttpHandler(Handler):
         # dot), it is static content, too (favicon.ico, robots.txt...)
         elif (len(parts) == 1) and ('.' in parts[0]):
             self.static = True
-            # This kind of file must exist in the app
-            parts.insert(0, config.model.appName)
+            # Get this file at the place configured in the UI config
+            base = config.ui.images.get(parts[0]) or 'appy'
+            parts.insert(0, base)
         # In any other case, dynamic content must be served
         else:
             self.static = False
