@@ -27,14 +27,19 @@ from appy.server.cookie import Cookie
 from appy.model.utils import Object as O
 
 #- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-LDAP_DISABLED   = 'LDAP config not enabled.'
-LDAP_CONNECT_KO = 'Could not connect to %s (%s).'
-LDAP_COUNTS     = '%d local active SSO users // %d LDAP users'
-LDAP_ACT        = '%d user(s) %sactivated: %s.'
-LDAP_NO_DEACT   = 'No user was deactivated.'
-SYNC_SUMMARY    = 'users synchronization: %d local user(s) created, %d ' \
-                  'updated, %d untouched and %d invalid entries. %s local ' \
-                  'user(s) deactivated and %d reactivated.'
+LDAP_DISABLED = 'LDAP config not enabled.'
+LDAP_CONN_KO  = 'Could not connect to %s (%s).'
+LDAP_CONN_ERR = 'LDAP connect error with login "%s" (%s).'
+LDAP_SRV_ERR  = '%s: connect error with login %s (%s).'
+LDAP_READING  = 'Reading users from %s...'
+LDAP_COUNTS   = '%d local active SSO users // %d LDAP users'
+LDAP_ACT      = '%d user(s) %sactivated: %s.'
+LDAP_NO_DEACT = 'No user was deactivated.'
+LDAP_QRY_ERR  = 'LDAP query error %s: %s'
+PRIV_SET      = '%s: automatic privileges set.'
+SYNC_SUMMARY  = 'users sync from %s: %d local user(s) created, %d updated, ' \
+                '%d untouched and %d invalid entries. %s local user(s) ' \
+                'deactivated and %d reactivated.'
 
 #- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 class Config:
@@ -244,7 +249,7 @@ class Config:
                 roles = getattr(privileges, 'roles', None)
                 if roles:
                     for role in roles: user.addRole(role)
-                tool.log('%s: automatic privileges set.' % login)
+                tool.log(PRIV_SET % login)
         # Update user password, if given
         if password:
             user.password = password
@@ -338,10 +343,10 @@ class Config:
         if not self.enabled: raise Exception(LDAP_DISABLED)
         # Get a connector to the LDAP server and connect to the LDAP server
         serverUri = self.getServerUri()
-        tool.log('reading users from %s...' % serverUri)
+        tool.log(LDAP_READING % serverUri)
         connector = LdapConnector(serverUri, tool=tool)
         success, msg = connector.connect(self.adminLogin, self.adminPassword)
-        if not success: raise Exception(LDAP_CONNECT_KO % (serverUri, msg))
+        if not success: raise Exception(LDAP_CONN_KO % (serverUri, msg))
         # Query the LDAP for users. Perform several queries to avoid having
         # error ldap.SIZELIMIT_EXCEEDED.
         params = self.getUserAttributes()
@@ -380,7 +385,7 @@ class Config:
         # Activate or deactivate users
         self.updateUserStates(tool, ldapUsers, counts, sso=sso)
         # Log the operation and return a message
-        message = SYNC_SUMMARY % (counts.created, counts.updated,
+        message = SYNC_SUMMARY % (serverUri, counts.created, counts.updated,
                                   counts.untouched, counts.wrong,
                                   counts.deactivated, counts.reactivated) 
         tool.log(message)
@@ -429,13 +434,11 @@ class LdapConnector:
             # When the ldap module is not there, trying to catch ldap.LDAPError
             # will raise an error.
             message = str(ae)
-            self.log('Ldap connect error with login %s (%s).' % \
-                     (login, message))
+            self.log(LDAP_CONN_ERR % (login, message))
             return False, message
         except ldap.LDAPError as le:
             message = str(le)
-            self.log('%s: connect error with login %s (%s).' % \
-                     (self.serverUri, login, message))
+            self.log(LDAP_SRV_ERR  % (self.serverUri, login, message))
             return False, message
 
     def getFilter(self, values, customPart=''):
@@ -465,6 +468,5 @@ class LdapConnector:
                 except ldap.TIMEOUT:
                     pass
         except ldap.LDAPError as le:
-            self.log('LDAP query error %s: %s' % \
-                     (le.__class__.__name__, str(le)))
+            self.log(LDAP_QRY_ERR % (le.__class__.__name__, str(le)))
 #- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
