@@ -97,7 +97,10 @@ class Response:
         # corresponding key in this dict is stored here.
         self.contentType = None
         # The HTTP version string
-        self.httpVersion = handler.server.config.server.getProtocolString()
+        config = handler.server.config.server
+        self.httpVersion = config.getProtocolString()
+        # The "SameSite" attribute for cookies
+        self.sameSite = config.sameSite
         # Has this response already been sent ? It may happen when producing
         # dynamic content whose result is a File.
         self.sent = False
@@ -206,7 +209,8 @@ class Response:
             # Manage special key containing cookies
             if name == 'Cookies':
                 for key, v in value.items():
-                    add(line('Set-Cookie: %s=%s' % (key, v)))
+                    add(line('Set-Cookie: %s=%s; SameSite=%s' % \
+                             (key, v, self.sameSite)))
             else:
                 # Manage any other key
                 add(line('%s: %s' % (name, value)))
