@@ -196,16 +196,19 @@ class Config:
         '''Identify the user from HTTP headers'''
         # Check if SSO is enabled
         if not self.enabled: return
-        # If the user we identify exists but as a user from another
+        # If the user to identify exists, but as a user from another
         # authentication source:
-        # - if it is a local user and self.convertLocalUsers is True, we
-        #   convert it to a SSO user;
-        # - else, we have a problem: we log a warning and force an
-        #   identification failure.
+        # - if it is a local user and self.convertLocalUsers is True, it will be
+        #   converted to a SSO user;
+        # - else, there is a problem: log a warning and force an identification
+        #   failure.
         login = headers and headers.get('HTTP_%s' % self.loginKey, None)
         if login:
+            # Apply a transform to the login when relevant
+            if self.ldap: login = self.ldap.applyLoginTransform(login)
+            # Search for this user
             user = tool.search1('User', login=login)
-            if user and (user.source != 'sso'):
+            if user and user.source != 'sso':
                 # Convert it when relevant
                 if self.convertLocalUsers:
                     user.convertTo('sso')
