@@ -85,8 +85,9 @@ class Traversal:
         self.r = None
         # The last encountered object
         self.o = None
-        # The last encountered field
-        self.field = None
+        # The last encountered field. For inner fields, the field name is
+        # explicitly mentioned in attribute p_self.fieldName.
+        self.field = self.fieldName = None
         # The last encountered transition
         self.transition = None
         # The PX context
@@ -260,6 +261,9 @@ class Traversal:
             self.context.o = self.o
             self.context.field = self.field
             self.context.layout = layout
+        # For inner fields, ensure the full name is in the context
+        if self.fieldName:
+            self.context.fieldName = self.fieldName
         # Secondly, execute the tied action if defined
         actionName = self.req.action
         if actionName:
@@ -313,6 +317,9 @@ class Traversal:
             field = r.getField(part)
             if field:
                 self.field = field
+                # For an inner field, store the full field name
+                if '*' in part:
+                    self.fieldName = part
                 return field
             # Is p_part a transition defined on the current object's workflow ?
             transition = r.getWorkflow().transitions.get(part)
@@ -326,7 +333,7 @@ class Traversal:
             raise NotFound(self.getPath())
         if isinstance(r, Base):
             self.o = r
-            self.field = self.transition = None
+            self.field = self.fieldName = self.transition = None
         return r
 
     def run(self):
