@@ -173,7 +173,7 @@ class Layout:
 
     pxRender = Px('''
      <table var="layoutCss=table.css_class;
-                 inTd=(layout == 'cell') and bool(column)|False"
+                 inTd=layout=='cell' and bool(column)|False"
        cellpadding=":table.cellpadding" cellspacing=":table.cellspacing"
        width=":'' if inTd else table.width"
        align=":'' if inTd else ui.Language.flip(table.align, dir)"
