@@ -46,20 +46,22 @@ class Message:
 
     # The message zone
     px = Px('''
-     <div var="validErrors=ui.Message.hasValidationErrors(handler)"
-          class=":'message fadedOut' if popup else 'message fadedOut'"
-          style=":'display:none' if not validErrors else 'display:block'"
-          id="appyMessage" onmouseenter="stopFadeout(this)">
+     <div id="appyMessage"
+          var="validErrors=ui.Message.hasValidationErrors(handler)"
+          style=":'display:none' if not validErrors else 'display:block'">
+      <script>Message.init(appyMessage)</script>
+
       <!-- The icon for closing the message -->
       <img src=":url('close.svg')" class="clickable iconS popupI"
            onclick="this.parentNode.style.display='none'" align=":dright"/>
+
       <!-- The message content -->
       <div id="appyMessageContent">:validErrors and _('validation_error')</div>
       <div if="validErrors"
            var2="validator=handler.validator">:handler.validator.pxErrors</div>
      </div>
      <script var="messages=ui.Message.consumeAll(handler)"
-             if="messages">::'showAppyMessage(%s)' % q(messages)</script>''',
+             if="messages">::'Message.show(%s)' % q(messages)</script>''',
 
      css='''
       .message { position: fixed; bottom: 30px; right: 0px;
@@ -76,15 +78,48 @@ class Message:
       .fadedOut { animation: fade |messageFadeout| 1;
                   animation-fill-mode: forwards }''',
 
+     # The Fader allows to manage the "fade out" effect on the message box
      js='''
-       function stopFadeout(div) {
-         var classes = div.className.split(' '),
-             x=classes.pop(),
-             clone=div.cloneNode(true);
-         // Creating a clone for the p_div will stop the animation
-         clone.className = classes.join(' ');
-         clone.onmouseenter = null;
-         div.parentNode.replaceChild(clone, div);
-       }'''
-     )
+       class Fader {
+
+         constructor(node){ /* Cross-link the fader and its anchor node */
+           node.fader = this;
+           this.node = node;
+         }
+
+         stop(restart) {
+           /* Resetting the "fade out" animation can only be performed by
+              replacing the target node with a clone. */
+           var node=this.node,
+               clone=node.cloneNode(true);
+           /* Configure the clone */
+           Message.init(clone, !restart);
+           node.parentNode.replaceChild(clone, node);
+           return clone;
+         }
+       }
+
+       // Static methods for managing the message zone
+       class Message {
+
+         // Initialises the DOM node representing the "message" zone
+         static init(node, noAnim) {
+           new Fader(node);
+           node.className = 'message';
+           if (!noAnim) {
+             node.className += ' fadedOut';
+             node.addEventListener('mouseenter',
+               function(event) {event.target.fader.stop()});
+           }
+           else node.onmouseenter = null;
+         }
+
+         // Display the message zone
+         static show(message) {
+           var zone = getNode('appyMessageContent');
+           zone.innerHTML = message;
+           zone.parentNode.style.display = 'block';
+         }
+       }
+       ''')
 #- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
