@@ -81,15 +81,16 @@ function getElementsHavingName(tag, name, forceTop) {
 
 // AJAX machinery
 var xhrObjects = new Array(); // An array of XMLHttpRequest objects
+
 function XhrObject() { // Wraps a XmlHttpRequest object
-  this.freed = 1; // Is this xhr object already dealing with a request or not?
-  this.xhr = false;
   this.xhr = new XMLHttpRequest();
-  this.hook = '';  /* The ID of the HTML element in the page that will be
-                      replaced by result of executing the Ajax request. */
-  this.onGet = ''; /* The name of a Javascript function to call once we
-                      receive the result. */
-  this.info = {};  /* An associative array for putting anything else */
+  this.freed = 1;      // Is this object already dealing with a request ?
+  this.hook = '';      /* The ID of the HTML element in the page that will be
+                          replaced by result of executing the Ajax request. */
+  this.onGet = '';     /* The name of a Javascript function to call once we
+                          receive the result. */
+  this.info = {};      // An associative array for putting anything else
+  this.append = false; // Replace or append the ajax response to the hook ?
 }
 
 /* When inserting HTML at some DOM node in a page via Ajax, scripts defined in
@@ -101,10 +102,13 @@ function evalInnerScripts(xhrObject, hookElem) {
   for (var i=0; i<scripts.length; i++) eval(scripts[i].innerHTML);
 }
 
-function injectChunk(tag, content, inner, searchTop){
-  // Injects the chunk of XHTML code p_content in this p_tag
+function injectChunk(tag, content, inner, searchTop, append){
+  /* Injects the chunk of XHTML code p_content in this p_tag, or append it to
+     the existing p_tag content if p_append is true. */
   var r = tag;
-  if (inner) r.innerHTML = content;
+  if (inner) {
+    r.innerHTML = append ? r.innerHTML + content : content;
+  }
   else {
     // Replace p_tag with a new one filled with p_content and return it
     if ((tag.tagName == 'TR') && content.startsWith('<!')) {
@@ -114,7 +118,10 @@ function injectChunk(tag, content, inner, searchTop){
     }
     var id = tag.id;
     if (id && searchTop) id = ':' + id;
-    tag.outerHTML = content;
+    /* Add p_content to the p_tag content or replace the whole p_tag, depending
+       on p_append. */
+    if (append) tag.innerHTML = tag.innerHTML + content;
+    else tag.outerHTML = content;
     if (id) r = getNode(id); // Get the new element
   }
   return r;
@@ -150,7 +157,7 @@ function getAjaxChunk(pos) {
     if (hookElem) {
       var content = rq.xhr.responseText,
           searchTop = rq.hook[0] == ':',
-          injected = injectChunk(hookElem, content, false, searchTop);
+          injected= injectChunk(hookElem, content, false, searchTop, rq.append);
       // Call a custom Javascript function if required
       if (rq.onGet) rq.onGet(rq, injected);
       // Refresh the whole page if requested
@@ -158,7 +165,7 @@ function getAjaxChunk(pos) {
       if (goto) window.top.location = goto;
       // Display the Appy message if present
       var msg = readCookie('AppyMessage');
-      if (msg) { showAppyMessage(msg,true); createCookie('AppyMessage', ''); }
+      if (msg) { updateAppyMessage(msg); createCookie('AppyMessage', ''); }
     }
     rq.freed = 1;
   }
@@ -174,7 +181,8 @@ function showPreloader(hook, waiting) {
   injectChunk(getNode(hook), loading('zone', waiting), true);
 }
 
-function askAjaxChunk(url, mode, params, hook, beforeSend, onGet, waiting) {
+function askAjaxChunk(url, mode, params, hook, beforeSend, onGet, waiting,
+                      append) {
   /* Ask a chunk of XHTML on the server at p_url, through a XMLHttpRequest.
      p_mode can be 'GET' or 'POST'. URL parameters or form data can be specified
      in associative array p_params.
@@ -199,7 +207,11 @@ function askAjaxChunk(url, mode, params, hook, beforeSend, onGet, waiting) {
      for the ajax result. If null, it will be "loading_big.gif". Other values
      can be "loading_link.gif", "loading_button.gif" or "loading_icon.gif".
      If string "none" is passed, there will be no icon at all.
+
+     If p_append is False or null, the hook content will be replaced with the
+     Ajax response. Else, it will be appended after the existing hook content.
   */
+
   // First, get a non-busy XMLHttpRequest object
   var sync = hook[0] == '*', pos = -1;
   for (var i=0; i < xhrObjects.length; i++) {
@@ -209,54 +221,54 @@ function askAjaxChunk(url, mode, params, hook, beforeSend, onGet, waiting) {
     pos = xhrObjects.length;
     xhrObjects[pos] = new XhrObject();
   }
-  xhrObjects[pos].hook = hook;
-  xhrObjects[pos].onGet = onGet;
-  if (xhrObjects[pos].xhr) {
-    var rq = xhrObjects[pos];
-    rq.freed = 0;
-    // Construct parameters
-    var allParams = ['ajax=True'], value = null;
-    if (params) {
-      for (var name in params) {
-        value = params[name];
-        if (typeof val == 'string') value = value.replace('+', '%2B');
-        allParams.push(name + '=' + value);
-      }
-    }
-    allParams = allParams.join('&');
-    // Call beforeSend if required
-    if (beforeSend) {
-       var res = beforeSend(rq, params);
-       if (res) allParams = allParams + res;
-    }
-    // Build the URL to call
-    var urlFull = url;
-    if (mode == 'GET') {
-      urlFull = urlFull + '?' + allParams;
-    }
-    // Display the pre-loader when appropriate
-    if (!sync) showPreloader(rq.hook, waiting);
-    // Perform the asynchronous HTTP GET or POST
-    rq.xhr.open(mode, urlFull, !sync);
-    if (mode == 'POST') { // Set the correct HTTP headers
-      rq.xhr.setRequestHeader('Content-Type',
-                              'application/x-www-form-urlencoded');
-    }
-    else { allParams = null; }
-    // For an asynchronous request, define the callback function
-    if (!sync) rq.xhr.onreadystatechange = function(){ getAjaxChunk(pos); }
-    // Perform the HTTP request
-    rq.xhr.send(allParams);
-    // Manage a sync request
-    if (sync) {
-      sessionStorage.setItem(hook.substr(1), rq.xhr.responseText);
-      rq.freed = 1;
+  var rq = xhrObjects[pos];
+  rq.hook = hook;
+  rq.onGet = onGet;
+  rq.append = append;
+  rq.freed = 0;
+    
+  // Construct parameters
+  var allParams = ['ajax=True'], value = null;
+  if (params) {
+    for (var name in params) {
+      value = params[name];
+      if (typeof val == 'string') value = value.replace('+', '%2B');
+      allParams.push(name + '=' + value);
     }
   }
+  allParams = allParams.join('&');
+  // Call beforeSend if required
+  if (beforeSend) {
+     var res = beforeSend(rq, params);
+     if (res) allParams = allParams + res;
+  }
+  // Build the URL to call
+  var urlFull = url;
+  if (mode == 'GET') {
+    urlFull = urlFull + '?' + allParams;
+  }
+  // Display the pre-loader when appropriate
+  if (!sync && !rq.append) showPreloader(rq.hook, waiting);
+  // Perform the asynchronous HTTP GET or POST
+  rq.xhr.open(mode, urlFull, !sync);
+  if (mode == 'POST') { // Set the correct HTTP headers
+    rq.xhr.setRequestHeader('Content-Type','application/x-www-form-urlencoded');
+  }
+  else { allParams = null; }
+  // For an asynchronous request, define the callback function
+  if (!sync) rq.xhr.onreadystatechange = function(){ getAjaxChunk(pos); }
+  // Perform the HTTP request
+  rq.xhr.send(allParams);
+  // Manage a sync request
+  if (sync) {
+    sessionStorage.setItem(hook.substr(1), rq.xhr.responseText);
+    rq.freed = 1;
+  }
 }
 
 // Object representing all the data required to perform an Ajax request
-function AjaxData(url, mode, params, hook, parentHook, beforeSend, onGet) {
+function AjaxData(url, mode, params, hook, parentHook, beforeSend, onGet,
+                  append) {
   this.url = url;
   this.mode = (!mode)? 'GET': mode;
   this.params = params;
@@ -266,6 +278,7 @@ function AjaxData(url, mode, params, hook, parentHook, beforeSend, onGet) {
   this.parentHook = parentHook;
   this.beforeSend = beforeSend;
   this.onGet = onGet;
+  this.append = append;
   // Inject this AjaxData instance into p_hook
   getNode(hook, true)['ajax'] = this;
   if (params && ('criteria' in params)) {
@@ -338,8 +351,9 @@ function askAjax(hook, form, params, waiting) {
     if ('mode' in params) { mode = params['mode']; delete params['mode'] };
     for (var key in params) d.params[key] = params[key];
   }
-  askAjaxChunk(d.url, mode, d.params, hook, d.beforeSend, evalInnerScripts,
-               waiting);
+  var onGet = d.onGet || evalInnerScripts;
+  askAjaxChunk(d.url, mode, d.params, hook, d.beforeSend, onGet, waiting,
+               d.append);
 }
 
 function askBunch(hook, start, maxPerPage) {
@@ -680,6 +694,15 @@ function toggleAllCbs(id) {
   initCbs(id);
 }
 
+// Toggle all checkboxes of a Ref or Select rendered on "edit" as checkboxes
+function toggleCheckboxes(cb) {
+  var name=cb.id.substring(0, cb.id.length-4),
+      checkboxes = getElementsHavingName('input', name, true);
+  for (var i=0; i < checkboxes.length; i++) {
+    checkboxes[i].checked = cb.checked;
+  }
+}
+
 // Shows/hides a dropdown menu
 function toggleDropdown(container, forcedValue){
   var dropdown = container.getElementsByClassName('dropdown')[0];
@@ -912,8 +935,8 @@ function backFromPopup() {
   }
   else {
     // We must ajax-refresh, on the main page, the node as defined in the popup
-    var nodeId = popup['back'];
-    if (nodeId && getNode(':' + nodeId)) askAjax(':' + nodeId);
+    var nodeId = popup['back'], node=(nodeId)? getNode(':' + nodeId): null;
+    if (node) { askAjax(':' + nodeId); }
     else window.parent.location = window.parent.location;
   }
 }
@@ -1048,9 +1071,10 @@ function createCookie(name, value, days) {
   if (days) {
     var date = new Date();
     date.setTime(date.getTime()+(days*24*60*60*1000));
-    var expires = "; expires=" + date.toGMTString();
-  } else expires = "";
-  document.cookie = name + "=" + encodeURIComponent(value) + expires + "; path=/;";
+    var expires = '; expires=' + date.toGMTString();
+  } else expires = '';
+  var v = encodeURIComponent(value);
+  document.cookie = name + "=" + v + expires + "; path=/; SameSite=" + sameSite;
 }
 
 function readCookie(name) {
@@ -1197,14 +1221,14 @@ function closePopup(popupId, clean, tryCancel) {
   return popup;
 }
 
-function showAppyMessage(message, forceTop) {
+function updateAppyMessage(message) {
+  // Retrieve the message zone. Reloading the fader will clone the zone.
+  var zone = getNode(':appyMessageContent').parentNode,
+      newZone = zone.fader.stop(true),
+      content = getNode(':appyMessageContent');
   // Fill the message zone with the message to display
-  var prefix = (forceTop)? ':' : '',
-      zone = getNode(prefix + 'appyMessageContent');
-  if (!zone) zone = getNode(':appyMessageContent');
-  zone.innerHTML = message;
-  // Display the message box
-  zone.parentNode.style.display = 'block';
+  content.innerHTML = message;
+  newZone.style.display = 'block';
 }
 
 // Function triggered when an action needs to be confirmed by the user
@@ -1391,7 +1415,7 @@ function onSelectObjects(popupId, initiatorId, objectUrl, mode, onav,
 }
 
 function onSelectObject(checkboxId, initiatorId, id, ckNum) {
-  // An object, whose ID is p_id, has been selected in a popup
+  // An object has been selected in a popup
   var checkbox = document.getElementById(checkboxId);
   if (ckNum) {
     // The object has been selected from a popup opened by ckeditor
@@ -1412,9 +1436,9 @@ function onSelectObject(checkboxId, initiatorId, id, ckNum) {
     else {
       /* Close the popup and directly refresh the initiator field with the
          selected object. */
-      var uids = checkbox.value;
+      var ids = checkbox.value;
       closePopup('iframePopup');
-      var params = {'selected': uids, 'semantics': 'checked'};
+      var params = {'selected': ids, 'semantics': 'checked'};
       askField(':'+initiatorId, siteUrl + '/' + id, 'edit', params, false);
     }
   }
