@@ -24,20 +24,18 @@ from appy.ui.criteria import Criteria
 
 #- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 class Title:
-    '''Manages the zone, mainly within lists, rendering the title of an object
-       and everything around it (sup- and sub-titles).'''
+    '''Manages the zone, within lists and grids, rendering the title of an
+       object and everything around it (sup- and sub-titles).'''
 
     @staticmethod
-    def showSub(class_, field):
-        '''Show button "details" only under field "title", if a method named
-           "getSubTitle" is defined on p_class_.'''
-        return (field.name == 'title') and class_.hasSubTitle()
+    def showToggleSub(class_, field, tool, from_=None):
+        '''Show icon "toggle sub-titles" when toggling sub-titles is enabled'''
+        return field.name == 'title' and class_.toggleSubTitles(tool, from_)
+
+    # Icon for hiding / showing the "sub-title" zone under an object's title
+    pxToggleSub = Px('''
+     <span onClick="toggleSubTitles()" class="clickable iconS">👀</span>''',
 
-    # Icon for hiding/showing the "sub-title" zone under an object's title
-    pxSub = Px('''
-     <img src=":url('toggleDetails')" class="clickable"
-          onclick="toggleSubTitles()"/>''',
-    
      js='''
       // Function that sets a value for showing/hiding sub-titles
       setSubTitles = function(value, tag) {
