@@ -80,7 +80,8 @@ class Validator:
             if message:
                 self.errors[field.name] = message
             else:
-                self.values[field.name] = field.getStorableValue(o, value)
+                self.values[field.name] = field.getStorableValue(o, value,
+                                                                 single=True)
             # Store this field
             self.fields.append(field)
             self.fieldsByName[field.name] = field
