@@ -3,7 +3,7 @@
 '''Utility module related to string manipulation'''
 
 #- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-# Copyright (C) 2007-2020 Gaetan Delannay
+# Copyright (C) 2007-2021 Gaetan Delannay
 
 # This file is part of Appy.
 
@@ -20,7 +20,8 @@
 # Appy. If not, see <http://www.gnu.org/licenses/>.
 
 #- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-import re, html
+import re
+
 from appy.utils import flipDict, asDict
 
 #- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -216,19 +217,6 @@ class Normalize:
         '''Returns a version of p_s whose non-digit chars have been removed'''
         return Normalize.string(s, class_.nonDigit)
 
-#- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-def formatText(text, format='html'):
-    '''Produces a representation of p_text into the desired p_format, which
-       is "html" by default.'''
-    if 'html' in format:
-        if format == 'html_from_text': text = html.escape(text)
-        r = text.replace('\r\n', '<br/>').replace('\n', '<br/>')
-    elif format == 'text':
-        r = text.replace('<br/>', '\n')
-    else:
-        r = text
-    return r
-
 #- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 def getStringFrom(o, stringify=True, c="'"):
     '''Returns a string representation for p_o that can be transported over
@@ -262,33 +250,41 @@ def getStringFrom(o, stringify=True, c="'"):
 def getDictFrom(s):
     '''Returns a dict from string representation p_s of the form
        "key1:value1,key2:value2".'''
-    res = {}
+    r = {}
     if s:
         for part in s.split(','):
-            key, value = part.split(':')
-            res[key] = value
-    return res
+            key, value = part.split(':', 1)
+            if value:
+                r[key] = value
+    return r
 
 #- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-def sadd(s, sub, sep=' '):
-    '''Adds sub-string p_sub into p_s, which is a list of sub-strings separated
-       by p_sep, and returns the updated string.'''
+def sadd(s, sub, sep=' ', append=True):
+    '''Appends sub-string p_sub into p_s, which is a list of sub-strings
+       separated by p_sep, and returns the updated string. If p_append is False,
+       p_sub is inserted at the start of p_s instead.'''
     if not sub: return s
     if not s: return sub
-    elems = set(s.split(sep)).union(set(sub.split(sep)))
-    return sep.join(elems)
+    r = s.split(sep)
+    for part in sub.split(sep):
+        if part not in r:
+            if append:
+                r.append(part)
+            else:
+                r.insert(0, part)
+    return sep.join(r)
 
 #- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 def sremove(s, sub, sep=' '):
     '''Removes sub-string p_sub from p_s, which is a list of sub-strings
-       separated by p_sep, and returns the updated string.'''
+       separated by p_sep, and returns the updated string.'''    
     if not sub: return s
     if not s: return s
-    elems = set(s.split(sep))
-    for elem in sub.split(sep):
-        if elem in elems:
-            elems.remove(elem)
-    return sep.join(elems)
+    r = s.split(sep)
+    for part in sub.split(sep):
+        if part in r:
+            r.remove(part)
+    return sep.join(r)
 
 #- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 def stringIsAmong(s, l):
